import datetime
import typing

import kubernetes.client

class V2beta1ResourceMetricSource:
    name: str
    target_average_utilization: typing.Optional[int]
    target_average_value: typing.Optional[str]
    def __init__(
        self,
        *,
        name: str,
        target_average_utilization: typing.Optional[int] = ...,
        target_average_value: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V2beta1ResourceMetricSourceDict: ...

class V2beta1ResourceMetricSourceDict(typing.TypedDict, total=False):
    name: str
    targetAverageUtilization: typing.Optional[int]
    targetAverageValue: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1NFSVolumeSource:
    path: str
    read_only: typing.Optional[bool]
    server: str
    def __init__(
        self, *, path: str, read_only: typing.Optional[bool] = ..., server: str
    ) -> None: ...
    def to_dict(self) -> V1NFSVolumeSourceDict: ...

class V1NFSVolumeSourceDict(typing.TypedDict, total=False):
    path: str
    readOnly: typing.Optional[bool]
    server: str



import datetime
import typing

import kubernetes.client

class V1PodTemplateSpec:
    metadata: typing.Optional[kubernetes.client.V1ObjectMeta]
    spec: typing.Optional[kubernetes.client.V1PodSpec]
    def __init__(
        self,
        *,
        metadata: typing.Optional[kubernetes.client.V1ObjectMeta] = ...,
        spec: typing.Optional[kubernetes.client.V1PodSpec] = ...
    ) -> None: ...
    def to_dict(self) -> V1PodTemplateSpecDict: ...

class V1PodTemplateSpecDict(typing.TypedDict, total=False):
    metadata: typing.Optional[kubernetes.client.V1ObjectMetaDict]
    spec: typing.Optional[kubernetes.client.V1PodSpecDict]



import datetime
import typing

import kubernetes.client

class V1VolumeNodeResources:
    count: typing.Optional[int]
    def __init__(self, *, count: typing.Optional[int] = ...) -> None: ...
    def to_dict(self) -> V1VolumeNodeResourcesDict: ...

class V1VolumeNodeResourcesDict(typing.TypedDict, total=False):
    count: typing.Optional[int]



import datetime
import typing

import kubernetes.client

class V1ScaleStatus:
    replicas: int
    selector: typing.Optional[str]
    def __init__(
        self, *, replicas: int, selector: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1ScaleStatusDict: ...

class V1ScaleStatusDict(typing.TypedDict, total=False):
    replicas: int
    selector: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1PersistentVolumeClaimStatus:
    access_modes: typing.Optional[list[str]]
    capacity: typing.Optional[dict[str, str]]
    conditions: typing.Optional[
        list[kubernetes.client.V1PersistentVolumeClaimCondition]
    ]
    phase: typing.Optional[str]
    def __init__(
        self,
        *,
        access_modes: typing.Optional[list[str]] = ...,
        capacity: typing.Optional[dict[str, str]] = ...,
        conditions: typing.Optional[
            list[kubernetes.client.V1PersistentVolumeClaimCondition]
        ] = ...,
        phase: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1PersistentVolumeClaimStatusDict: ...

class V1PersistentVolumeClaimStatusDict(typing.TypedDict, total=False):
    accessModes: typing.Optional[list[str]]
    capacity: typing.Optional[dict[str, str]]
    conditions: typing.Optional[
        list[kubernetes.client.V1PersistentVolumeClaimConditionDict]
    ]
    phase: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1DownwardAPIVolumeSource:
    default_mode: typing.Optional[int]
    items: typing.Optional[list[kubernetes.client.V1DownwardAPIVolumeFile]]
    def __init__(
        self,
        *,
        default_mode: typing.Optional[int] = ...,
        items: typing.Optional[list[kubernetes.client.V1DownwardAPIVolumeFile]] = ...
    ) -> None: ...
    def to_dict(self) -> V1DownwardAPIVolumeSourceDict: ...

class V1DownwardAPIVolumeSourceDict(typing.TypedDict, total=False):
    defaultMode: typing.Optional[int]
    items: typing.Optional[list[kubernetes.client.V1DownwardAPIVolumeFileDict]]



import datetime
import typing

import kubernetes.client

class V1HostAlias:
    hostnames: typing.Optional[list[str]]
    ip: typing.Optional[str]
    def __init__(
        self,
        *,
        hostnames: typing.Optional[list[str]] = ...,
        ip: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1HostAliasDict: ...

class V1HostAliasDict(typing.TypedDict, total=False):
    hostnames: typing.Optional[list[str]]
    ip: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1NodeDaemonEndpoints:
    kubelet_endpoint: typing.Optional[kubernetes.client.V1DaemonEndpoint]
    def __init__(
        self,
        *,
        kubelet_endpoint: typing.Optional[kubernetes.client.V1DaemonEndpoint] = ...
    ) -> None: ...
    def to_dict(self) -> V1NodeDaemonEndpointsDict: ...

class V1NodeDaemonEndpointsDict(typing.TypedDict, total=False):
    kubeletEndpoint: typing.Optional[kubernetes.client.V1DaemonEndpointDict]



import datetime
import typing

import kubernetes.client

class V1ScopeSelector:
    match_expressions: typing.Optional[
        list[kubernetes.client.V1ScopedResourceSelectorRequirement]
    ]
    def __init__(
        self,
        *,
        match_expressions: typing.Optional[
            list[kubernetes.client.V1ScopedResourceSelectorRequirement]
        ] = ...
    ) -> None: ...
    def to_dict(self) -> V1ScopeSelectorDict: ...

class V1ScopeSelectorDict(typing.TypedDict, total=False):
    matchExpressions: typing.Optional[
        list[kubernetes.client.V1ScopedResourceSelectorRequirementDict]
    ]



import datetime
import typing

import kubernetes.client

class V1JobSpec:
    active_deadline_seconds: typing.Optional[int]
    backoff_limit: typing.Optional[int]
    completions: typing.Optional[int]
    manual_selector: typing.Optional[bool]
    parallelism: typing.Optional[int]
    selector: typing.Optional[kubernetes.client.V1LabelSelector]
    template: kubernetes.client.V1PodTemplateSpec
    ttl_seconds_after_finished: typing.Optional[int]
    def __init__(
        self,
        *,
        active_deadline_seconds: typing.Optional[int] = ...,
        backoff_limit: typing.Optional[int] = ...,
        completions: typing.Optional[int] = ...,
        manual_selector: typing.Optional[bool] = ...,
        parallelism: typing.Optional[int] = ...,
        selector: typing.Optional[kubernetes.client.V1LabelSelector] = ...,
        template: kubernetes.client.V1PodTemplateSpec,
        ttl_seconds_after_finished: typing.Optional[int] = ...
    ) -> None: ...
    def to_dict(self) -> V1JobSpecDict: ...

class V1JobSpecDict(typing.TypedDict, total=False):
    activeDeadlineSeconds: typing.Optional[int]
    backoffLimit: typing.Optional[int]
    completions: typing.Optional[int]
    manualSelector: typing.Optional[bool]
    parallelism: typing.Optional[int]
    selector: typing.Optional[kubernetes.client.V1LabelSelectorDict]
    template: kubernetes.client.V1PodTemplateSpecDict
    ttlSecondsAfterFinished: typing.Optional[int]



import datetime
import typing

import kubernetes.client

class V1PortStatus:
    error: typing.Optional[str]
    port: int
    protocol: str
    def __init__(
        self, *, error: typing.Optional[str] = ..., port: int, protocol: str
    ) -> None: ...
    def to_dict(self) -> V1PortStatusDict: ...

class V1PortStatusDict(typing.TypedDict, total=False):
    error: typing.Optional[str]
    port: int
    protocol: str



import datetime
import typing

import kubernetes.client

class V2beta2MetricSpec:
    container_resource: typing.Optional[
        kubernetes.client.V2beta2ContainerResourceMetricSource
    ]
    external: typing.Optional[kubernetes.client.V2beta2ExternalMetricSource]
    object: typing.Optional[kubernetes.client.V2beta2ObjectMetricSource]
    pods: typing.Optional[kubernetes.client.V2beta2PodsMetricSource]
    resource: typing.Optional[kubernetes.client.V2beta2ResourceMetricSource]
    type: str
    def __init__(
        self,
        *,
        container_resource: typing.Optional[
            kubernetes.client.V2beta2ContainerResourceMetricSource
        ] = ...,
        external: typing.Optional[kubernetes.client.V2beta2ExternalMetricSource] = ...,
        object: typing.Optional[kubernetes.client.V2beta2ObjectMetricSource] = ...,
        pods: typing.Optional[kubernetes.client.V2beta2PodsMetricSource] = ...,
        resource: typing.Optional[kubernetes.client.V2beta2ResourceMetricSource] = ...,
        type: str
    ) -> None: ...
    def to_dict(self) -> V2beta2MetricSpecDict: ...

class V2beta2MetricSpecDict(typing.TypedDict, total=False):
    containerResource: typing.Optional[
        kubernetes.client.V2beta2ContainerResourceMetricSourceDict
    ]
    external: typing.Optional[kubernetes.client.V2beta2ExternalMetricSourceDict]
    object: typing.Optional[kubernetes.client.V2beta2ObjectMetricSourceDict]
    pods: typing.Optional[kubernetes.client.V2beta2PodsMetricSourceDict]
    resource: typing.Optional[kubernetes.client.V2beta2ResourceMetricSourceDict]
    type: str



import datetime
import typing

import kubernetes.client

class V1ClusterRoleList:
    api_version: typing.Optional[str]
    items: list[kubernetes.client.V1ClusterRole]
    kind: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ListMeta]
    def __init__(
        self,
        *,
        api_version: typing.Optional[str] = ...,
        items: list[kubernetes.client.V1ClusterRole],
        kind: typing.Optional[str] = ...,
        metadata: typing.Optional[kubernetes.client.V1ListMeta] = ...
    ) -> None: ...
    def to_dict(self) -> V1ClusterRoleListDict: ...

class V1ClusterRoleListDict(typing.TypedDict, total=False):
    apiVersion: typing.Optional[str]
    items: list[kubernetes.client.V1ClusterRoleDict]
    kind: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ListMetaDict]



import datetime
import typing

import kubernetes.client

class V1ResourceQuotaSpec:
    hard: typing.Optional[dict[str, str]]
    scope_selector: typing.Optional[kubernetes.client.V1ScopeSelector]
    scopes: typing.Optional[list[str]]
    def __init__(
        self,
        *,
        hard: typing.Optional[dict[str, str]] = ...,
        scope_selector: typing.Optional[kubernetes.client.V1ScopeSelector] = ...,
        scopes: typing.Optional[list[str]] = ...
    ) -> None: ...
    def to_dict(self) -> V1ResourceQuotaSpecDict: ...

class V1ResourceQuotaSpecDict(typing.TypedDict, total=False):
    hard: typing.Optional[dict[str, str]]
    scopeSelector: typing.Optional[kubernetes.client.V1ScopeSelectorDict]
    scopes: typing.Optional[list[str]]



import datetime
import typing

import kubernetes.client

class V1beta1LimitedPriorityLevelConfiguration:
    assured_concurrency_shares: typing.Optional[int]
    limit_response: typing.Optional[kubernetes.client.V1beta1LimitResponse]
    def __init__(
        self,
        *,
        assured_concurrency_shares: typing.Optional[int] = ...,
        limit_response: typing.Optional[kubernetes.client.V1beta1LimitResponse] = ...
    ) -> None: ...
    def to_dict(self) -> V1beta1LimitedPriorityLevelConfigurationDict: ...

class V1beta1LimitedPriorityLevelConfigurationDict(typing.TypedDict, total=False):
    assuredConcurrencyShares: typing.Optional[int]
    limitResponse: typing.Optional[kubernetes.client.V1beta1LimitResponseDict]



import datetime
import typing

import kubernetes.client

class V2beta2MetricStatus:
    container_resource: typing.Optional[
        kubernetes.client.V2beta2ContainerResourceMetricStatus
    ]
    external: typing.Optional[kubernetes.client.V2beta2ExternalMetricStatus]
    object: typing.Optional[kubernetes.client.V2beta2ObjectMetricStatus]
    pods: typing.Optional[kubernetes.client.V2beta2PodsMetricStatus]
    resource: typing.Optional[kubernetes.client.V2beta2ResourceMetricStatus]
    type: str
    def __init__(
        self,
        *,
        container_resource: typing.Optional[
            kubernetes.client.V2beta2ContainerResourceMetricStatus
        ] = ...,
        external: typing.Optional[kubernetes.client.V2beta2ExternalMetricStatus] = ...,
        object: typing.Optional[kubernetes.client.V2beta2ObjectMetricStatus] = ...,
        pods: typing.Optional[kubernetes.client.V2beta2PodsMetricStatus] = ...,
        resource: typing.Optional[kubernetes.client.V2beta2ResourceMetricStatus] = ...,
        type: str
    ) -> None: ...
    def to_dict(self) -> V2beta2MetricStatusDict: ...

class V2beta2MetricStatusDict(typing.TypedDict, total=False):
    containerResource: typing.Optional[
        kubernetes.client.V2beta2ContainerResourceMetricStatusDict
    ]
    external: typing.Optional[kubernetes.client.V2beta2ExternalMetricStatusDict]
    object: typing.Optional[kubernetes.client.V2beta2ObjectMetricStatusDict]
    pods: typing.Optional[kubernetes.client.V2beta2PodsMetricStatusDict]
    resource: typing.Optional[kubernetes.client.V2beta2ResourceMetricStatusDict]
    type: str



import datetime
import typing

import kubernetes.client

class V1beta1EndpointConditions:
    ready: typing.Optional[bool]
    serving: typing.Optional[bool]
    terminating: typing.Optional[bool]
    def __init__(
        self,
        *,
        ready: typing.Optional[bool] = ...,
        serving: typing.Optional[bool] = ...,
        terminating: typing.Optional[bool] = ...
    ) -> None: ...
    def to_dict(self) -> V1beta1EndpointConditionsDict: ...

class V1beta1EndpointConditionsDict(typing.TypedDict, total=False):
    ready: typing.Optional[bool]
    serving: typing.Optional[bool]
    terminating: typing.Optional[bool]



import datetime
import typing

import kubernetes.client

class V1VolumeProjection:
    config_map: typing.Optional[kubernetes.client.V1ConfigMapProjection]
    downward_api: typing.Optional[kubernetes.client.V1DownwardAPIProjection]
    secret: typing.Optional[kubernetes.client.V1SecretProjection]
    service_account_token: typing.Optional[
        kubernetes.client.V1ServiceAccountTokenProjection
    ]
    def __init__(
        self,
        *,
        config_map: typing.Optional[kubernetes.client.V1ConfigMapProjection] = ...,
        downward_api: typing.Optional[kubernetes.client.V1DownwardAPIProjection] = ...,
        secret: typing.Optional[kubernetes.client.V1SecretProjection] = ...,
        service_account_token: typing.Optional[
            kubernetes.client.V1ServiceAccountTokenProjection
        ] = ...
    ) -> None: ...
    def to_dict(self) -> V1VolumeProjectionDict: ...

class V1VolumeProjectionDict(typing.TypedDict, total=False):
    configMap: typing.Optional[kubernetes.client.V1ConfigMapProjectionDict]
    downwardAPI: typing.Optional[kubernetes.client.V1DownwardAPIProjectionDict]
    secret: typing.Optional[kubernetes.client.V1SecretProjectionDict]
    serviceAccountToken: typing.Optional[
        kubernetes.client.V1ServiceAccountTokenProjectionDict
    ]



import datetime
import typing

import kubernetes.client

class V1EndpointSubset:
    addresses: typing.Optional[list[kubernetes.client.V1EndpointAddress]]
    not_ready_addresses: typing.Optional[list[kubernetes.client.V1EndpointAddress]]
    ports: typing.Optional[list[kubernetes.client.V1EndpointPort]]
    def __init__(
        self,
        *,
        addresses: typing.Optional[list[kubernetes.client.V1EndpointAddress]] = ...,
        not_ready_addresses: typing.Optional[
            list[kubernetes.client.V1EndpointAddress]
        ] = ...,
        ports: typing.Optional[list[kubernetes.client.V1EndpointPort]] = ...
    ) -> None: ...
    def to_dict(self) -> V1EndpointSubsetDict: ...

class V1EndpointSubsetDict(typing.TypedDict, total=False):
    addresses: typing.Optional[list[kubernetes.client.V1EndpointAddressDict]]
    notReadyAddresses: typing.Optional[list[kubernetes.client.V1EndpointAddressDict]]
    ports: typing.Optional[list[kubernetes.client.V1EndpointPortDict]]



import datetime
import typing

import kubernetes.client

class V1beta1CronJobSpec:
    concurrency_policy: typing.Optional[str]
    failed_jobs_history_limit: typing.Optional[int]
    job_template: kubernetes.client.V1beta1JobTemplateSpec
    schedule: str
    starting_deadline_seconds: typing.Optional[int]
    successful_jobs_history_limit: typing.Optional[int]
    suspend: typing.Optional[bool]
    def __init__(
        self,
        *,
        concurrency_policy: typing.Optional[str] = ...,
        failed_jobs_history_limit: typing.Optional[int] = ...,
        job_template: kubernetes.client.V1beta1JobTemplateSpec,
        schedule: str,
        starting_deadline_seconds: typing.Optional[int] = ...,
        successful_jobs_history_limit: typing.Optional[int] = ...,
        suspend: typing.Optional[bool] = ...
    ) -> None: ...
    def to_dict(self) -> V1beta1CronJobSpecDict: ...

class V1beta1CronJobSpecDict(typing.TypedDict, total=False):
    concurrencyPolicy: typing.Optional[str]
    failedJobsHistoryLimit: typing.Optional[int]
    jobTemplate: kubernetes.client.V1beta1JobTemplateSpecDict
    schedule: str
    startingDeadlineSeconds: typing.Optional[int]
    successfulJobsHistoryLimit: typing.Optional[int]
    suspend: typing.Optional[bool]



import datetime
import typing

import kubernetes.client

class V1EndpointAddress:
    hostname: typing.Optional[str]
    ip: str
    node_name: typing.Optional[str]
    target_ref: typing.Optional[kubernetes.client.V1ObjectReference]
    def __init__(
        self,
        *,
        hostname: typing.Optional[str] = ...,
        ip: str,
        node_name: typing.Optional[str] = ...,
        target_ref: typing.Optional[kubernetes.client.V1ObjectReference] = ...
    ) -> None: ...
    def to_dict(self) -> V1EndpointAddressDict: ...

class V1EndpointAddressDict(typing.TypedDict, total=False):
    hostname: typing.Optional[str]
    ip: str
    nodeName: typing.Optional[str]
    targetRef: typing.Optional[kubernetes.client.V1ObjectReferenceDict]



import datetime
import typing

import kubernetes.client

class V1LocalObjectReference:
    name: typing.Optional[str]
    def __init__(self, *, name: typing.Optional[str] = ...) -> None: ...
    def to_dict(self) -> V1LocalObjectReferenceDict: ...

class V1LocalObjectReferenceDict(typing.TypedDict, total=False):
    name: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1ComponentCondition:
    error: typing.Optional[str]
    message: typing.Optional[str]
    status: str
    type: str
    def __init__(
        self,
        *,
        error: typing.Optional[str] = ...,
        message: typing.Optional[str] = ...,
        status: str,
        type: str
    ) -> None: ...
    def to_dict(self) -> V1ComponentConditionDict: ...

class V1ComponentConditionDict(typing.TypedDict, total=False):
    error: typing.Optional[str]
    message: typing.Optional[str]
    status: str
    type: str



import datetime
import typing

import kubernetes.client

class V1ScaleSpec:
    replicas: typing.Optional[int]
    def __init__(self, *, replicas: typing.Optional[int] = ...) -> None: ...
    def to_dict(self) -> V1ScaleSpecDict: ...

class V1ScaleSpecDict(typing.TypedDict, total=False):
    replicas: typing.Optional[int]



import datetime
import typing

import kubernetes.client

class V1JobStatus:
    active: typing.Optional[int]
    completion_time: typing.Optional[datetime.datetime]
    conditions: typing.Optional[list[kubernetes.client.V1JobCondition]]
    failed: typing.Optional[int]
    start_time: typing.Optional[datetime.datetime]
    succeeded: typing.Optional[int]
    def __init__(
        self,
        *,
        active: typing.Optional[int] = ...,
        completion_time: typing.Optional[datetime.datetime] = ...,
        conditions: typing.Optional[list[kubernetes.client.V1JobCondition]] = ...,
        failed: typing.Optional[int] = ...,
        start_time: typing.Optional[datetime.datetime] = ...,
        succeeded: typing.Optional[int] = ...
    ) -> None: ...
    def to_dict(self) -> V1JobStatusDict: ...

class V1JobStatusDict(typing.TypedDict, total=False):
    active: typing.Optional[int]
    completionTime: typing.Optional[datetime.datetime]
    conditions: typing.Optional[list[kubernetes.client.V1JobConditionDict]]
    failed: typing.Optional[int]
    startTime: typing.Optional[datetime.datetime]
    succeeded: typing.Optional[int]



import datetime
import typing

import kubernetes.client

class V1APIVersions:
    api_version: typing.Optional[str]
    kind: typing.Optional[str]
    server_address_by_client_cid_rs: list[kubernetes.client.V1ServerAddressByClientCIDR]
    versions: list[str]
    def __init__(
        self,
        *,
        api_version: typing.Optional[str] = ...,
        kind: typing.Optional[str] = ...,
        server_address_by_client_cid_rs: list[
            kubernetes.client.V1ServerAddressByClientCIDR
        ],
        versions: list[str]
    ) -> None: ...
    def to_dict(self) -> V1APIVersionsDict: ...

class V1APIVersionsDict(typing.TypedDict, total=False):
    apiVersion: typing.Optional[str]
    kind: typing.Optional[str]
    serverAddressByClientCIDRs: list[kubernetes.client.V1ServerAddressByClientCIDRDict]
    versions: list[str]



import datetime
import typing

import kubernetes.client

class V1RollingUpdateDaemonSet:
    max_unavailable: typing.Optional[typing.Any]
    def __init__(
        self, *, max_unavailable: typing.Optional[typing.Any] = ...
    ) -> None: ...
    def to_dict(self) -> V1RollingUpdateDaemonSetDict: ...

class V1RollingUpdateDaemonSetDict(typing.TypedDict, total=False):
    maxUnavailable: typing.Optional[typing.Any]



import datetime
import typing

import kubernetes.client

class V2beta2ObjectMetricSource:
    described_object: kubernetes.client.V2beta2CrossVersionObjectReference
    metric: kubernetes.client.V2beta2MetricIdentifier
    target: kubernetes.client.V2beta2MetricTarget
    def __init__(
        self,
        *,
        described_object: kubernetes.client.V2beta2CrossVersionObjectReference,
        metric: kubernetes.client.V2beta2MetricIdentifier,
        target: kubernetes.client.V2beta2MetricTarget
    ) -> None: ...
    def to_dict(self) -> V2beta2ObjectMetricSourceDict: ...

class V2beta2ObjectMetricSourceDict(typing.TypedDict, total=False):
    describedObject: kubernetes.client.V2beta2CrossVersionObjectReferenceDict
    metric: kubernetes.client.V2beta2MetricIdentifierDict
    target: kubernetes.client.V2beta2MetricTargetDict



import datetime
import typing

import kubernetes.client

class CoreV1Event:
    action: typing.Optional[str]
    api_version: typing.Optional[str]
    count: typing.Optional[int]
    event_time: typing.Optional[datetime.datetime]
    first_timestamp: typing.Optional[datetime.datetime]
    involved_object: kubernetes.client.V1ObjectReference
    kind: typing.Optional[str]
    last_timestamp: typing.Optional[datetime.datetime]
    message: typing.Optional[str]
    metadata: kubernetes.client.V1ObjectMeta
    reason: typing.Optional[str]
    related: typing.Optional[kubernetes.client.V1ObjectReference]
    reporting_component: typing.Optional[str]
    reporting_instance: typing.Optional[str]
    series: typing.Optional[kubernetes.client.CoreV1EventSeries]
    source: typing.Optional[kubernetes.client.V1EventSource]
    type: typing.Optional[str]
    def __init__(
        self,
        *,
        action: typing.Optional[str] = ...,
        api_version: typing.Optional[str] = ...,
        count: typing.Optional[int] = ...,
        event_time: typing.Optional[datetime.datetime] = ...,
        first_timestamp: typing.Optional[datetime.datetime] = ...,
        involved_object: kubernetes.client.V1ObjectReference,
        kind: typing.Optional[str] = ...,
        last_timestamp: typing.Optional[datetime.datetime] = ...,
        message: typing.Optional[str] = ...,
        metadata: kubernetes.client.V1ObjectMeta,
        reason: typing.Optional[str] = ...,
        related: typing.Optional[kubernetes.client.V1ObjectReference] = ...,
        reporting_component: typing.Optional[str] = ...,
        reporting_instance: typing.Optional[str] = ...,
        series: typing.Optional[kubernetes.client.CoreV1EventSeries] = ...,
        source: typing.Optional[kubernetes.client.V1EventSource] = ...,
        type: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> CoreV1EventDict: ...

class CoreV1EventDict(typing.TypedDict, total=False):
    action: typing.Optional[str]
    apiVersion: typing.Optional[str]
    count: typing.Optional[int]
    eventTime: typing.Optional[datetime.datetime]
    firstTimestamp: typing.Optional[datetime.datetime]
    involvedObject: kubernetes.client.V1ObjectReferenceDict
    kind: typing.Optional[str]
    lastTimestamp: typing.Optional[datetime.datetime]
    message: typing.Optional[str]
    metadata: kubernetes.client.V1ObjectMetaDict
    reason: typing.Optional[str]
    related: typing.Optional[kubernetes.client.V1ObjectReferenceDict]
    reportingComponent: typing.Optional[str]
    reportingInstance: typing.Optional[str]
    series: typing.Optional[kubernetes.client.CoreV1EventSeriesDict]
    source: typing.Optional[kubernetes.client.V1EventSourceDict]
    type: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1CertificateSigningRequestSpec:
    extra: typing.Optional[dict[str, list[str]]]
    groups: typing.Optional[list[str]]
    request: str
    signer_name: str
    uid: typing.Optional[str]
    usages: typing.Optional[list[str]]
    username: typing.Optional[str]
    def __init__(
        self,
        *,
        extra: typing.Optional[dict[str, list[str]]] = ...,
        groups: typing.Optional[list[str]] = ...,
        request: str,
        signer_name: str,
        uid: typing.Optional[str] = ...,
        usages: typing.Optional[list[str]] = ...,
        username: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1CertificateSigningRequestSpecDict: ...

class V1CertificateSigningRequestSpecDict(typing.TypedDict, total=False):
    extra: typing.Optional[dict[str, list[str]]]
    groups: typing.Optional[list[str]]
    request: str
    signerName: str
    uid: typing.Optional[str]
    usages: typing.Optional[list[str]]
    username: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1Subject:
    api_group: typing.Optional[str]
    kind: str
    name: str
    namespace: typing.Optional[str]
    def __init__(
        self,
        *,
        api_group: typing.Optional[str] = ...,
        kind: str,
        name: str,
        namespace: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1SubjectDict: ...

class V1SubjectDict(typing.TypedDict, total=False):
    apiGroup: typing.Optional[str]
    kind: str
    name: str
    namespace: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1PersistentVolumeClaimVolumeSource:
    claim_name: str
    read_only: typing.Optional[bool]
    def __init__(
        self, *, claim_name: str, read_only: typing.Optional[bool] = ...
    ) -> None: ...
    def to_dict(self) -> V1PersistentVolumeClaimVolumeSourceDict: ...

class V1PersistentVolumeClaimVolumeSourceDict(typing.TypedDict, total=False):
    claimName: str
    readOnly: typing.Optional[bool]



import datetime
import typing

import kubernetes.client

class V1ProjectedVolumeSource:
    default_mode: typing.Optional[int]
    sources: typing.Optional[list[kubernetes.client.V1VolumeProjection]]
    def __init__(
        self,
        *,
        default_mode: typing.Optional[int] = ...,
        sources: typing.Optional[list[kubernetes.client.V1VolumeProjection]] = ...
    ) -> None: ...
    def to_dict(self) -> V1ProjectedVolumeSourceDict: ...

class V1ProjectedVolumeSourceDict(typing.TypedDict, total=False):
    defaultMode: typing.Optional[int]
    sources: typing.Optional[list[kubernetes.client.V1VolumeProjectionDict]]



import datetime
import typing

import kubernetes.client

class V1ObjectMeta:
    annotations: typing.Optional[dict[str, str]]
    cluster_name: typing.Optional[str]
    creation_timestamp: typing.Optional[datetime.datetime]
    deletion_grace_period_seconds: typing.Optional[int]
    deletion_timestamp: typing.Optional[datetime.datetime]
    finalizers: typing.Optional[list[str]]
    generate_name: typing.Optional[str]
    generation: typing.Optional[int]
    labels: typing.Optional[dict[str, str]]
    managed_fields: typing.Optional[list[kubernetes.client.V1ManagedFieldsEntry]]
    name: typing.Optional[str]
    namespace: typing.Optional[str]
    owner_references: typing.Optional[list[kubernetes.client.V1OwnerReference]]
    resource_version: typing.Optional[str]
    self_link: typing.Optional[str]
    uid: typing.Optional[str]
    def __init__(
        self,
        *,
        annotations: typing.Optional[dict[str, str]] = ...,
        cluster_name: typing.Optional[str] = ...,
        creation_timestamp: typing.Optional[datetime.datetime] = ...,
        deletion_grace_period_seconds: typing.Optional[int] = ...,
        deletion_timestamp: typing.Optional[datetime.datetime] = ...,
        finalizers: typing.Optional[list[str]] = ...,
        generate_name: typing.Optional[str] = ...,
        generation: typing.Optional[int] = ...,
        labels: typing.Optional[dict[str, str]] = ...,
        managed_fields: typing.Optional[
            list[kubernetes.client.V1ManagedFieldsEntry]
        ] = ...,
        name: typing.Optional[str] = ...,
        namespace: typing.Optional[str] = ...,
        owner_references: typing.Optional[
            list[kubernetes.client.V1OwnerReference]
        ] = ...,
        resource_version: typing.Optional[str] = ...,
        self_link: typing.Optional[str] = ...,
        uid: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1ObjectMetaDict: ...

class V1ObjectMetaDict(typing.TypedDict, total=False):
    annotations: typing.Optional[dict[str, str]]
    clusterName: typing.Optional[str]
    creationTimestamp: typing.Optional[datetime.datetime]
    deletionGracePeriodSeconds: typing.Optional[int]
    deletionTimestamp: typing.Optional[datetime.datetime]
    finalizers: typing.Optional[list[str]]
    generateName: typing.Optional[str]
    generation: typing.Optional[int]
    labels: typing.Optional[dict[str, str]]
    managedFields: typing.Optional[list[kubernetes.client.V1ManagedFieldsEntryDict]]
    name: typing.Optional[str]
    namespace: typing.Optional[str]
    ownerReferences: typing.Optional[list[kubernetes.client.V1OwnerReferenceDict]]
    resourceVersion: typing.Optional[str]
    selfLink: typing.Optional[str]
    uid: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1APIResourceList:
    api_version: typing.Optional[str]
    group_version: str
    kind: typing.Optional[str]
    resources: list[kubernetes.client.V1APIResource]
    def __init__(
        self,
        *,
        api_version: typing.Optional[str] = ...,
        group_version: str,
        kind: typing.Optional[str] = ...,
        resources: list[kubernetes.client.V1APIResource]
    ) -> None: ...
    def to_dict(self) -> V1APIResourceListDict: ...

class V1APIResourceListDict(typing.TypedDict, total=False):
    apiVersion: typing.Optional[str]
    groupVersion: str
    kind: typing.Optional[str]
    resources: list[kubernetes.client.V1APIResourceDict]



import datetime
import typing

import kubernetes.client

class V1beta1LeaseSpec:
    acquire_time: typing.Optional[datetime.datetime]
    holder_identity: typing.Optional[str]
    lease_duration_seconds: typing.Optional[int]
    lease_transitions: typing.Optional[int]
    renew_time: typing.Optional[datetime.datetime]
    def __init__(
        self,
        *,
        acquire_time: typing.Optional[datetime.datetime] = ...,
        holder_identity: typing.Optional[str] = ...,
        lease_duration_seconds: typing.Optional[int] = ...,
        lease_transitions: typing.Optional[int] = ...,
        renew_time: typing.Optional[datetime.datetime] = ...
    ) -> None: ...
    def to_dict(self) -> V1beta1LeaseSpecDict: ...

class V1beta1LeaseSpecDict(typing.TypedDict, total=False):
    acquireTime: typing.Optional[datetime.datetime]
    holderIdentity: typing.Optional[str]
    leaseDurationSeconds: typing.Optional[int]
    leaseTransitions: typing.Optional[int]
    renewTime: typing.Optional[datetime.datetime]



import datetime
import typing

import kubernetes.client

class V1LocalVolumeSource:
    fs_type: typing.Optional[str]
    path: str
    def __init__(self, *, fs_type: typing.Optional[str] = ..., path: str) -> None: ...
    def to_dict(self) -> V1LocalVolumeSourceDict: ...

class V1LocalVolumeSourceDict(typing.TypedDict, total=False):
    fsType: typing.Optional[str]
    path: str



import datetime
import typing

import kubernetes.client

class V1IngressRule:
    host: typing.Optional[str]
    http: typing.Optional[kubernetes.client.V1HTTPIngressRuleValue]
    def __init__(
        self,
        *,
        host: typing.Optional[str] = ...,
        http: typing.Optional[kubernetes.client.V1HTTPIngressRuleValue] = ...
    ) -> None: ...
    def to_dict(self) -> V1IngressRuleDict: ...

class V1IngressRuleDict(typing.TypedDict, total=False):
    host: typing.Optional[str]
    http: typing.Optional[kubernetes.client.V1HTTPIngressRuleValueDict]



import datetime
import typing

import kubernetes.client

class V1beta1RoleRef:
    api_group: str
    kind: str
    name: str
    def __init__(self, *, api_group: str, kind: str, name: str) -> None: ...
    def to_dict(self) -> V1beta1RoleRefDict: ...

class V1beta1RoleRefDict(typing.TypedDict, total=False):
    apiGroup: str
    kind: str
    name: str



import datetime
import typing

import kubernetes.client

class V2beta2ContainerResourceMetricSource:
    container: str
    name: str
    target: kubernetes.client.V2beta2MetricTarget
    def __init__(
        self,
        *,
        container: str,
        name: str,
        target: kubernetes.client.V2beta2MetricTarget
    ) -> None: ...
    def to_dict(self) -> V2beta2ContainerResourceMetricSourceDict: ...

class V2beta2ContainerResourceMetricSourceDict(typing.TypedDict, total=False):
    container: str
    name: str
    target: kubernetes.client.V2beta2MetricTargetDict



import datetime
import typing

import kubernetes.client

class V1NamespaceSpec:
    finalizers: typing.Optional[list[str]]
    def __init__(self, *, finalizers: typing.Optional[list[str]] = ...) -> None: ...
    def to_dict(self) -> V1NamespaceSpecDict: ...

class V1NamespaceSpecDict(typing.TypedDict, total=False):
    finalizers: typing.Optional[list[str]]



import datetime
import typing

import kubernetes.client

class V1LoadBalancerStatus:
    ingress: typing.Optional[list[kubernetes.client.V1LoadBalancerIngress]]
    def __init__(
        self,
        *,
        ingress: typing.Optional[list[kubernetes.client.V1LoadBalancerIngress]] = ...
    ) -> None: ...
    def to_dict(self) -> V1LoadBalancerStatusDict: ...

class V1LoadBalancerStatusDict(typing.TypedDict, total=False):
    ingress: typing.Optional[list[kubernetes.client.V1LoadBalancerIngressDict]]



import datetime
import typing

import kubernetes.client

class V1PodAffinityTerm:
    label_selector: typing.Optional[kubernetes.client.V1LabelSelector]
    namespaces: typing.Optional[list[str]]
    topology_key: str
    def __init__(
        self,
        *,
        label_selector: typing.Optional[kubernetes.client.V1LabelSelector] = ...,
        namespaces: typing.Optional[list[str]] = ...,
        topology_key: str
    ) -> None: ...
    def to_dict(self) -> V1PodAffinityTermDict: ...

class V1PodAffinityTermDict(typing.TypedDict, total=False):
    labelSelector: typing.Optional[kubernetes.client.V1LabelSelectorDict]
    namespaces: typing.Optional[list[str]]
    topologyKey: str



import datetime
import typing

import kubernetes.client

class V1SeccompProfile:
    localhost_profile: typing.Optional[str]
    type: str
    def __init__(
        self, *, localhost_profile: typing.Optional[str] = ..., type: str
    ) -> None: ...
    def to_dict(self) -> V1SeccompProfileDict: ...

class V1SeccompProfileDict(typing.TypedDict, total=False):
    localhostProfile: typing.Optional[str]
    type: str



import typing

import kubernetes.client

class CoordinationV1beta1Api:
    def __init__(
        self, api_client: typing.Optional[kubernetes.client.ApiClient] = ...
    ) -> None: ...
    def get_api_resources(self) -> kubernetes.client.V1APIResourceList: ...
    def list_lease_for_all_namespaces(
        self,
        *,
        allow_watch_bookmarks: typing.Optional[bool] = ...,
        _continue: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        pretty: typing.Optional[str] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...,
        watch: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1beta1LeaseList: ...
    def list_namespaced_lease(
        self,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        allow_watch_bookmarks: typing.Optional[bool] = ...,
        _continue: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...,
        watch: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1beta1LeaseList: ...
    def create_namespaced_lease(
        self,
        namespace: str,
        body: kubernetes.client.V1beta1Lease,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1beta1Lease: ...
    def delete_collection_namespaced_lease(
        self,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        body: typing.Optional[kubernetes.client.V1DeleteOptions] = ...,
        _continue: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        grace_period_seconds: typing.Optional[int] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        orphan_dependents: typing.Optional[bool] = ...,
        propagation_policy: typing.Optional[str] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...
    ) -> kubernetes.client.V1Status: ...
    def read_namespaced_lease(
        self,
        name: str,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        exact: typing.Optional[bool] = ...,
        export: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1beta1Lease: ...
    def replace_namespaced_lease(
        self,
        name: str,
        namespace: str,
        body: kubernetes.client.V1beta1Lease,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> kubernetes.client.V1beta1Lease: ...
    def delete_namespaced_lease(
        self,
        name: str,
        namespace: str,
        *,
        pretty: typing.Optional[str] = ...,
        body: typing.Optional[kubernetes.client.V1DeleteOptions] = ...,
        dry_run: typing.Optional[str] = ...,
        grace_period_seconds: typing.Optional[int] = ...,
        orphan_dependents: typing.Optional[bool] = ...,
        propagation_policy: typing.Optional[str] = ...
    ) -> kubernetes.client.V1Status: ...
    def patch_namespaced_lease(
        self,
        name: str,
        namespace: str,
        body: typing.Any,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...,
        force: typing.Optional[bool] = ...
    ) -> kubernetes.client.V1beta1Lease: ...



import datetime
import typing

import kubernetes.client

class V2beta2ResourceMetricStatus:
    current: kubernetes.client.V2beta2MetricValueStatus
    name: str
    def __init__(
        self, *, current: kubernetes.client.V2beta2MetricValueStatus, name: str
    ) -> None: ...
    def to_dict(self) -> V2beta2ResourceMetricStatusDict: ...

class V2beta2ResourceMetricStatusDict(typing.TypedDict, total=False):
    current: kubernetes.client.V2beta2MetricValueStatusDict
    name: str



import datetime
import typing

import kubernetes.client

class V1beta1ResourcePolicyRule:
    api_groups: list[str]
    cluster_scope: typing.Optional[bool]
    namespaces: typing.Optional[list[str]]
    resources: list[str]
    verbs: list[str]
    def __init__(
        self,
        *,
        api_groups: list[str],
        cluster_scope: typing.Optional[bool] = ...,
        namespaces: typing.Optional[list[str]] = ...,
        resources: list[str],
        verbs: list[str]
    ) -> None: ...
    def to_dict(self) -> V1beta1ResourcePolicyRuleDict: ...

class V1beta1ResourcePolicyRuleDict(typing.TypedDict, total=False):
    apiGroups: list[str]
    clusterScope: typing.Optional[bool]
    namespaces: typing.Optional[list[str]]
    resources: list[str]
    verbs: list[str]



import datetime
import typing

import kubernetes.client

class V1EndpointPort:
    app_protocol: typing.Optional[str]
    name: typing.Optional[str]
    port: int
    protocol: typing.Optional[str]
    def __init__(
        self,
        *,
        app_protocol: typing.Optional[str] = ...,
        name: typing.Optional[str] = ...,
        port: int,
        protocol: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1EndpointPortDict: ...

class V1EndpointPortDict(typing.TypedDict, total=False):
    appProtocol: typing.Optional[str]
    name: typing.Optional[str]
    port: int
    protocol: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1NetworkPolicyPeer:
    ip_block: typing.Optional[kubernetes.client.V1IPBlock]
    namespace_selector: typing.Optional[kubernetes.client.V1LabelSelector]
    pod_selector: typing.Optional[kubernetes.client.V1LabelSelector]
    def __init__(
        self,
        *,
        ip_block: typing.Optional[kubernetes.client.V1IPBlock] = ...,
        namespace_selector: typing.Optional[kubernetes.client.V1LabelSelector] = ...,
        pod_selector: typing.Optional[kubernetes.client.V1LabelSelector] = ...
    ) -> None: ...
    def to_dict(self) -> V1NetworkPolicyPeerDict: ...

class V1NetworkPolicyPeerDict(typing.TypedDict, total=False):
    ipBlock: typing.Optional[kubernetes.client.V1IPBlockDict]
    namespaceSelector: typing.Optional[kubernetes.client.V1LabelSelectorDict]
    podSelector: typing.Optional[kubernetes.client.V1LabelSelectorDict]



import typing

import kubernetes.client

class CustomObjectsApi:
    def __init__(
        self, api_client: typing.Optional[kubernetes.client.ApiClient] = ...
    ) -> None: ...
    def list_cluster_custom_object(
        self,
        group: str,
        version: str,
        plural: str,
        *,
        pretty: typing.Optional[str] = ...,
        allow_watch_bookmarks: typing.Optional[bool] = ...,
        _continue: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...,
        watch: typing.Optional[bool] = ...
    ) -> typing.Any: ...
    def create_cluster_custom_object(
        self,
        group: str,
        version: str,
        plural: str,
        body: typing.Any,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> None: ...
    def delete_collection_cluster_custom_object(
        self,
        group: str,
        version: str,
        plural: str,
        *,
        pretty: typing.Optional[str] = ...,
        body: typing.Optional[kubernetes.client.V1DeleteOptions] = ...,
        grace_period_seconds: typing.Optional[int] = ...,
        orphan_dependents: typing.Optional[bool] = ...,
        propagation_policy: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...
    ) -> typing.Any: ...
    def list_namespaced_custom_object(
        self,
        group: str,
        version: str,
        namespace: str,
        plural: str,
        *,
        pretty: typing.Optional[str] = ...,
        allow_watch_bookmarks: typing.Optional[bool] = ...,
        _continue: typing.Optional[str] = ...,
        field_selector: typing.Optional[str] = ...,
        label_selector: typing.Optional[str] = ...,
        limit: typing.Optional[int] = ...,
        resource_version: typing.Optional[str] = ...,
        resource_version_match: typing.Optional[str] = ...,
        timeout_seconds: typing.Optional[int] = ...,
        watch: typing.Optional[bool] = ...
    ) -> typing.Any: ...
    def create_namespaced_custom_object(
        self,
        group: str,
        version: str,
        namespace: str,
        plural: str,
        body: typing.Any,
        *,
        pretty: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> None: ...
    def delete_collection_namespaced_custom_object(
        self,
        group: str,
        version: str,
        namespace: str,
        plural: str,
        *,
        pretty: typing.Optional[str] = ...,
        body: typing.Optional[kubernetes.client.V1DeleteOptions] = ...,
        grace_period_seconds: typing.Optional[int] = ...,
        orphan_dependents: typing.Optional[bool] = ...,
        propagation_policy: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...
    ) -> typing.Any: ...
    def get_cluster_custom_object(
        self, group: str, version: str, plural: str, name: str
    ) -> typing.Any: ...
    def replace_cluster_custom_object(
        self,
        group: str,
        version: str,
        plural: str,
        name: str,
        body: typing.Any,
        *,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> typing.Any: ...
    def delete_cluster_custom_object(
        self,
        group: str,
        version: str,
        plural: str,
        name: str,
        *,
        body: typing.Optional[kubernetes.client.V1DeleteOptions] = ...,
        grace_period_seconds: typing.Optional[int] = ...,
        orphan_dependents: typing.Optional[bool] = ...,
        propagation_policy: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...
    ) -> typing.Any: ...
    def patch_cluster_custom_object(
        self,
        group: str,
        version: str,
        plural: str,
        name: str,
        body: typing.Any,
        *,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...,
        force: typing.Optional[bool] = ...
    ) -> typing.Any: ...
    def get_cluster_custom_object_status(
        self, group: str, version: str, plural: str, name: str
    ) -> typing.Any: ...
    def replace_cluster_custom_object_status(
        self,
        group: str,
        version: str,
        plural: str,
        name: str,
        body: typing.Any,
        *,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> typing.Any: ...
    def patch_cluster_custom_object_status(
        self,
        group: str,
        version: str,
        plural: str,
        name: str,
        body: typing.Any,
        *,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...,
        force: typing.Optional[bool] = ...
    ) -> typing.Any: ...
    def get_cluster_custom_object_scale(
        self, group: str, version: str, plural: str, name: str
    ) -> typing.Any: ...
    def replace_cluster_custom_object_scale(
        self,
        group: str,
        version: str,
        plural: str,
        name: str,
        body: typing.Any,
        *,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> typing.Any: ...
    def patch_cluster_custom_object_scale(
        self,
        group: str,
        version: str,
        plural: str,
        name: str,
        body: typing.Any,
        *,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...,
        force: typing.Optional[bool] = ...
    ) -> typing.Any: ...
    def get_namespaced_custom_object(
        self, group: str, version: str, namespace: str, plural: str, name: str
    ) -> typing.Any: ...
    def replace_namespaced_custom_object(
        self,
        group: str,
        version: str,
        namespace: str,
        plural: str,
        name: str,
        body: typing.Any,
        *,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> typing.Any: ...
    def delete_namespaced_custom_object(
        self,
        group: str,
        version: str,
        namespace: str,
        plural: str,
        name: str,
        *,
        body: typing.Optional[kubernetes.client.V1DeleteOptions] = ...,
        grace_period_seconds: typing.Optional[int] = ...,
        orphan_dependents: typing.Optional[bool] = ...,
        propagation_policy: typing.Optional[str] = ...,
        dry_run: typing.Optional[str] = ...
    ) -> typing.Any: ...
    def patch_namespaced_custom_object(
        self,
        group: str,
        version: str,
        namespace: str,
        plural: str,
        name: str,
        body: typing.Any,
        *,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...,
        force: typing.Optional[bool] = ...
    ) -> typing.Any: ...
    def get_namespaced_custom_object_status(
        self, group: str, version: str, namespace: str, plural: str, name: str
    ) -> typing.Any: ...
    def replace_namespaced_custom_object_status(
        self,
        group: str,
        version: str,
        namespace: str,
        plural: str,
        name: str,
        body: typing.Any,
        *,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> typing.Any: ...
    def patch_namespaced_custom_object_status(
        self,
        group: str,
        version: str,
        namespace: str,
        plural: str,
        name: str,
        body: typing.Any,
        *,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...,
        force: typing.Optional[bool] = ...
    ) -> typing.Any: ...
    def get_namespaced_custom_object_scale(
        self, group: str, version: str, namespace: str, plural: str, name: str
    ) -> typing.Any: ...
    def replace_namespaced_custom_object_scale(
        self,
        group: str,
        version: str,
        namespace: str,
        plural: str,
        name: str,
        body: typing.Any,
        *,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...
    ) -> typing.Any: ...
    def patch_namespaced_custom_object_scale(
        self,
        group: str,
        version: str,
        namespace: str,
        plural: str,
        name: str,
        body: typing.Any,
        *,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...,
        force: typing.Optional[bool] = ...
    ) -> typing.Any: ...



import datetime
import typing

import kubernetes.client

class V1beta1VolumeAttachmentSpec:
    attacher: str
    node_name: str
    source: kubernetes.client.V1beta1VolumeAttachmentSource
    def __init__(
        self,
        *,
        attacher: str,
        node_name: str,
        source: kubernetes.client.V1beta1VolumeAttachmentSource
    ) -> None: ...
    def to_dict(self) -> V1beta1VolumeAttachmentSpecDict: ...

class V1beta1VolumeAttachmentSpecDict(typing.TypedDict, total=False):
    attacher: str
    nodeName: str
    source: kubernetes.client.V1beta1VolumeAttachmentSourceDict



import datetime
import typing

import kubernetes.client

class V1ConfigMap:
    api_version: typing.Optional[str]
    binary_data: typing.Optional[dict[str, str]]
    data: typing.Optional[dict[str, str]]
    immutable: typing.Optional[bool]
    kind: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ObjectMeta]
    def __init__(
        self,
        *,
        api_version: typing.Optional[str] = ...,
        binary_data: typing.Optional[dict[str, str]] = ...,
        data: typing.Optional[dict[str, str]] = ...,
        immutable: typing.Optional[bool] = ...,
        kind: typing.Optional[str] = ...,
        metadata: typing.Optional[kubernetes.client.V1ObjectMeta] = ...
    ) -> None: ...
    def to_dict(self) -> V1ConfigMapDict: ...

class V1ConfigMapDict(typing.TypedDict, total=False):
    apiVersion: typing.Optional[str]
    binaryData: typing.Optional[dict[str, str]]
    data: typing.Optional[dict[str, str]]
    immutable: typing.Optional[bool]
    kind: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ObjectMetaDict]



import datetime
import typing

import kubernetes.client

class V1SELinuxOptions:
    level: typing.Optional[str]
    role: typing.Optional[str]
    type: typing.Optional[str]
    user: typing.Optional[str]
    def __init__(
        self,
        *,
        level: typing.Optional[str] = ...,
        role: typing.Optional[str] = ...,
        type: typing.Optional[str] = ...,
        user: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1SELinuxOptionsDict: ...

class V1SELinuxOptionsDict(typing.TypedDict, total=False):
    level: typing.Optional[str]
    role: typing.Optional[str]
    type: typing.Optional[str]
    user: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1ResourceQuotaStatus:
    hard: typing.Optional[dict[str, str]]
    used: typing.Optional[dict[str, str]]
    def __init__(
        self,
        *,
        hard: typing.Optional[dict[str, str]] = ...,
        used: typing.Optional[dict[str, str]] = ...
    ) -> None: ...
    def to_dict(self) -> V1ResourceQuotaStatusDict: ...

class V1ResourceQuotaStatusDict(typing.TypedDict, total=False):
    hard: typing.Optional[dict[str, str]]
    used: typing.Optional[dict[str, str]]



import typing

import kubernetes.client

class AuthenticationV1Api:
    def __init__(
        self, api_client: typing.Optional[kubernetes.client.ApiClient] = ...
    ) -> None: ...
    def get_api_resources(self) -> kubernetes.client.V1APIResourceList: ...
    def create_token_review(
        self,
        body: kubernetes.client.V1TokenReview,
        *,
        dry_run: typing.Optional[str] = ...,
        field_manager: typing.Optional[str] = ...,
        pretty: typing.Optional[str] = ...
    ) -> kubernetes.client.V1TokenReview: ...



import datetime
import typing

import kubernetes.client

class V1RollingUpdateStatefulSetStrategy:
    partition: typing.Optional[int]
    def __init__(self, *, partition: typing.Optional[int] = ...) -> None: ...
    def to_dict(self) -> V1RollingUpdateStatefulSetStrategyDict: ...

class V1RollingUpdateStatefulSetStrategyDict(typing.TypedDict, total=False):
    partition: typing.Optional[int]



import datetime
import typing

import kubernetes.client

class V1ISCSIVolumeSource:
    chap_auth_discovery: typing.Optional[bool]
    chap_auth_session: typing.Optional[bool]
    fs_type: typing.Optional[str]
    initiator_name: typing.Optional[str]
    iqn: str
    iscsi_interface: typing.Optional[str]
    lun: int
    portals: typing.Optional[list[str]]
    read_only: typing.Optional[bool]
    secret_ref: typing.Optional[kubernetes.client.V1LocalObjectReference]
    target_portal: str
    def __init__(
        self,
        *,
        chap_auth_discovery: typing.Optional[bool] = ...,
        chap_auth_session: typing.Optional[bool] = ...,
        fs_type: typing.Optional[str] = ...,
        initiator_name: typing.Optional[str] = ...,
        iqn: str,
        iscsi_interface: typing.Optional[str] = ...,
        lun: int,
        portals: typing.Optional[list[str]] = ...,
        read_only: typing.Optional[bool] = ...,
        secret_ref: typing.Optional[kubernetes.client.V1LocalObjectReference] = ...,
        target_portal: str
    ) -> None: ...
    def to_dict(self) -> V1ISCSIVolumeSourceDict: ...

class V1ISCSIVolumeSourceDict(typing.TypedDict, total=False):
    chapAuthDiscovery: typing.Optional[bool]
    chapAuthSession: typing.Optional[bool]
    fsType: typing.Optional[str]
    initiatorName: typing.Optional[str]
    iqn: str
    iscsiInterface: typing.Optional[str]
    lun: int
    portals: typing.Optional[list[str]]
    readOnly: typing.Optional[bool]
    secretRef: typing.Optional[kubernetes.client.V1LocalObjectReferenceDict]
    targetPortal: str



import datetime
import typing

import kubernetes.client

class V1IngressClass:
    api_version: typing.Optional[str]
    kind: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ObjectMeta]
    spec: typing.Optional[kubernetes.client.V1IngressClassSpec]
    def __init__(
        self,
        *,
        api_version: typing.Optional[str] = ...,
        kind: typing.Optional[str] = ...,
        metadata: typing.Optional[kubernetes.client.V1ObjectMeta] = ...,
        spec: typing.Optional[kubernetes.client.V1IngressClassSpec] = ...
    ) -> None: ...
    def to_dict(self) -> V1IngressClassDict: ...

class V1IngressClassDict(typing.TypedDict, total=False):
    apiVersion: typing.Optional[str]
    kind: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ObjectMetaDict]
    spec: typing.Optional[kubernetes.client.V1IngressClassSpecDict]



import datetime
import typing

import kubernetes.client

class V1APIServiceStatus:
    conditions: typing.Optional[list[kubernetes.client.V1APIServiceCondition]]
    def __init__(
        self,
        *,
        conditions: typing.Optional[list[kubernetes.client.V1APIServiceCondition]] = ...
    ) -> None: ...
    def to_dict(self) -> V1APIServiceStatusDict: ...

class V1APIServiceStatusDict(typing.TypedDict, total=False):
    conditions: typing.Optional[list[kubernetes.client.V1APIServiceConditionDict]]



import datetime
import typing

import kubernetes.client

class V1ReplicaSetStatus:
    available_replicas: typing.Optional[int]
    conditions: typing.Optional[list[kubernetes.client.V1ReplicaSetCondition]]
    fully_labeled_replicas: typing.Optional[int]
    observed_generation: typing.Optional[int]
    ready_replicas: typing.Optional[int]
    replicas: int
    def __init__(
        self,
        *,
        available_replicas: typing.Optional[int] = ...,
        conditions: typing.Optional[
            list[kubernetes.client.V1ReplicaSetCondition]
        ] = ...,
        fully_labeled_replicas: typing.Optional[int] = ...,
        observed_generation: typing.Optional[int] = ...,
        ready_replicas: typing.Optional[int] = ...,
        replicas: int
    ) -> None: ...
    def to_dict(self) -> V1ReplicaSetStatusDict: ...

class V1ReplicaSetStatusDict(typing.TypedDict, total=False):
    availableReplicas: typing.Optional[int]
    conditions: typing.Optional[list[kubernetes.client.V1ReplicaSetConditionDict]]
    fullyLabeledReplicas: typing.Optional[int]
    observedGeneration: typing.Optional[int]
    readyReplicas: typing.Optional[int]
    replicas: int



import datetime
import typing

import kubernetes.client

class V1beta1AllowedHostPath:
    path_prefix: typing.Optional[str]
    read_only: typing.Optional[bool]
    def __init__(
        self,
        *,
        path_prefix: typing.Optional[str] = ...,
        read_only: typing.Optional[bool] = ...
    ) -> None: ...
    def to_dict(self) -> V1beta1AllowedHostPathDict: ...

class V1beta1AllowedHostPathDict(typing.TypedDict, total=False):
    pathPrefix: typing.Optional[str]
    readOnly: typing.Optional[bool]



import datetime
import typing

import kubernetes.client

class V1ScopedResourceSelectorRequirement:
    operator: str
    scope_name: str
    values: typing.Optional[list[str]]
    def __init__(
        self,
        *,
        operator: str,
        scope_name: str,
        values: typing.Optional[list[str]] = ...
    ) -> None: ...
    def to_dict(self) -> V1ScopedResourceSelectorRequirementDict: ...

class V1ScopedResourceSelectorRequirementDict(typing.TypedDict, total=False):
    operator: str
    scopeName: str
    values: typing.Optional[list[str]]



import datetime
import typing

import kubernetes.client

class V1beta1CustomResourceSubresourceScale:
    label_selector_path: typing.Optional[str]
    spec_replicas_path: str
    status_replicas_path: str
    def __init__(
        self,
        *,
        label_selector_path: typing.Optional[str] = ...,
        spec_replicas_path: str,
        status_replicas_path: str
    ) -> None: ...
    def to_dict(self) -> V1beta1CustomResourceSubresourceScaleDict: ...

class V1beta1CustomResourceSubresourceScaleDict(typing.TypedDict, total=False):
    labelSelectorPath: typing.Optional[str]
    specReplicasPath: str
    statusReplicasPath: str



import datetime
import typing

import kubernetes.client

class V1NonResourceRule:
    non_resource_ur_ls: typing.Optional[list[str]]
    verbs: list[str]
    def __init__(
        self, *, non_resource_ur_ls: typing.Optional[list[str]] = ..., verbs: list[str]
    ) -> None: ...
    def to_dict(self) -> V1NonResourceRuleDict: ...

class V1NonResourceRuleDict(typing.TypedDict, total=False):
    nonResourceURLs: typing.Optional[list[str]]
    verbs: list[str]



import datetime
import typing

import kubernetes.client

class V1WeightedPodAffinityTerm:
    pod_affinity_term: kubernetes.client.V1PodAffinityTerm
    weight: int
    def __init__(
        self, *, pod_affinity_term: kubernetes.client.V1PodAffinityTerm, weight: int
    ) -> None: ...
    def to_dict(self) -> V1WeightedPodAffinityTermDict: ...

class V1WeightedPodAffinityTermDict(typing.TypedDict, total=False):
    podAffinityTerm: kubernetes.client.V1PodAffinityTermDict
    weight: int



import datetime
import typing

import kubernetes.client

class V1PreferredSchedulingTerm:
    preference: kubernetes.client.V1NodeSelectorTerm
    weight: int
    def __init__(
        self, *, preference: kubernetes.client.V1NodeSelectorTerm, weight: int
    ) -> None: ...
    def to_dict(self) -> V1PreferredSchedulingTermDict: ...

class V1PreferredSchedulingTermDict(typing.TypedDict, total=False):
    preference: kubernetes.client.V1NodeSelectorTermDict
    weight: int



import datetime
import typing

import kubernetes.client

class V1FlexPersistentVolumeSource:
    driver: str
    fs_type: typing.Optional[str]
    options: typing.Optional[dict[str, str]]
    read_only: typing.Optional[bool]
    secret_ref: typing.Optional[kubernetes.client.V1SecretReference]
    def __init__(
        self,
        *,
        driver: str,
        fs_type: typing.Optional[str] = ...,
        options: typing.Optional[dict[str, str]] = ...,
        read_only: typing.Optional[bool] = ...,
        secret_ref: typing.Optional[kubernetes.client.V1SecretReference] = ...
    ) -> None: ...
    def to_dict(self) -> V1FlexPersistentVolumeSourceDict: ...

class V1FlexPersistentVolumeSourceDict(typing.TypedDict, total=False):
    driver: str
    fsType: typing.Optional[str]
    options: typing.Optional[dict[str, str]]
    readOnly: typing.Optional[bool]
    secretRef: typing.Optional[kubernetes.client.V1SecretReferenceDict]



import datetime
import typing

import kubernetes.client

class V2beta2HorizontalPodAutoscalerStatus:
    conditions: list[kubernetes.client.V2beta2HorizontalPodAutoscalerCondition]
    current_metrics: typing.Optional[list[kubernetes.client.V2beta2MetricStatus]]
    current_replicas: int
    desired_replicas: int
    last_scale_time: typing.Optional[datetime.datetime]
    observed_generation: typing.Optional[int]
    def __init__(
        self,
        *,
        conditions: list[kubernetes.client.V2beta2HorizontalPodAutoscalerCondition],
        current_metrics: typing.Optional[
            list[kubernetes.client.V2beta2MetricStatus]
        ] = ...,
        current_replicas: int,
        desired_replicas: int,
        last_scale_time: typing.Optional[datetime.datetime] = ...,
        observed_generation: typing.Optional[int] = ...
    ) -> None: ...
    def to_dict(self) -> V2beta2HorizontalPodAutoscalerStatusDict: ...

class V2beta2HorizontalPodAutoscalerStatusDict(typing.TypedDict, total=False):
    conditions: list[kubernetes.client.V2beta2HorizontalPodAutoscalerConditionDict]
    currentMetrics: typing.Optional[list[kubernetes.client.V2beta2MetricStatusDict]]
    currentReplicas: int
    desiredReplicas: int
    lastScaleTime: typing.Optional[datetime.datetime]
    observedGeneration: typing.Optional[int]



import datetime
import typing

import kubernetes.client

class V1NodeAffinity:
    preferred_during_scheduling_ignored_during_execution: typing.Optional[
        list[kubernetes.client.V1PreferredSchedulingTerm]
    ]
    required_during_scheduling_ignored_during_execution: typing.Optional[
        kubernetes.client.V1NodeSelector
    ]
    def __init__(
        self,
        *,
        preferred_during_scheduling_ignored_during_execution: typing.Optional[
            list[kubernetes.client.V1PreferredSchedulingTerm]
        ] = ...,
        required_during_scheduling_ignored_during_execution: typing.Optional[
            kubernetes.client.V1NodeSelector
        ] = ...
    ) -> None: ...
    def to_dict(self) -> V1NodeAffinityDict: ...

class V1NodeAffinityDict(typing.TypedDict, total=False):
    preferredDuringSchedulingIgnoredDuringExecution: typing.Optional[
        list[kubernetes.client.V1PreferredSchedulingTermDict]
    ]
    requiredDuringSchedulingIgnoredDuringExecution: typing.Optional[
        kubernetes.client.V1NodeSelectorDict
    ]



import datetime
import typing

import kubernetes.client

class V1IPBlock:
    cidr: str
    _except: typing.Optional[list[str]]
    def __init__(
        self, *, cidr: str, _except: typing.Optional[list[str]] = ...
    ) -> None: ...
    def to_dict(self) -> V1IPBlockDict: ...

class V1IPBlockDict(typing.TypedDict, total=False):
    cidr: str
    _except: typing.Optional[list[str]]



import datetime
import typing

import kubernetes.client

class V1KeyToPath:
    key: str
    mode: typing.Optional[int]
    path: str
    def __init__(
        self, *, key: str, mode: typing.Optional[int] = ..., path: str
    ) -> None: ...
    def to_dict(self) -> V1KeyToPathDict: ...

class V1KeyToPathDict(typing.TypedDict, total=False):
    key: str
    mode: typing.Optional[int]
    path: str



import datetime
import typing

import kubernetes.client

class V1RollingUpdateDeployment:
    max_surge: typing.Optional[typing.Any]
    max_unavailable: typing.Optional[typing.Any]
    def __init__(
        self,
        *,
        max_surge: typing.Optional[typing.Any] = ...,
        max_unavailable: typing.Optional[typing.Any] = ...
    ) -> None: ...
    def to_dict(self) -> V1RollingUpdateDeploymentDict: ...

class V1RollingUpdateDeploymentDict(typing.TypedDict, total=False):
    maxSurge: typing.Optional[typing.Any]
    maxUnavailable: typing.Optional[typing.Any]



import datetime
import typing

import kubernetes.client

class V1GitRepoVolumeSource:
    directory: typing.Optional[str]
    repository: str
    revision: typing.Optional[str]
    def __init__(
        self,
        *,
        directory: typing.Optional[str] = ...,
        repository: str,
        revision: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1GitRepoVolumeSourceDict: ...

class V1GitRepoVolumeSourceDict(typing.TypedDict, total=False):
    directory: typing.Optional[str]
    repository: str
    revision: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1ReplicaSetSpec:
    min_ready_seconds: typing.Optional[int]
    replicas: typing.Optional[int]
    selector: kubernetes.client.V1LabelSelector
    template: typing.Optional[kubernetes.client.V1PodTemplateSpec]
    def __init__(
        self,
        *,
        min_ready_seconds: typing.Optional[int] = ...,
        replicas: typing.Optional[int] = ...,
        selector: kubernetes.client.V1LabelSelector,
        template: typing.Optional[kubernetes.client.V1PodTemplateSpec] = ...
    ) -> None: ...
    def to_dict(self) -> V1ReplicaSetSpecDict: ...

class V1ReplicaSetSpecDict(typing.TypedDict, total=False):
    minReadySeconds: typing.Optional[int]
    replicas: typing.Optional[int]
    selector: kubernetes.client.V1LabelSelectorDict
    template: typing.Optional[kubernetes.client.V1PodTemplateSpecDict]



import datetime
import typing

import kubernetes.client

class V1TopologySelectorLabelRequirement:
    key: str
    values: list[str]
    def __init__(self, *, key: str, values: list[str]) -> None: ...
    def to_dict(self) -> V1TopologySelectorLabelRequirementDict: ...

class V1TopologySelectorLabelRequirementDict(typing.TypedDict, total=False):
    key: str
    values: list[str]



import datetime
import typing

import kubernetes.client

class V1beta1TokenRequest:
    audience: str
    expiration_seconds: typing.Optional[int]
    def __init__(
        self, *, audience: str, expiration_seconds: typing.Optional[int] = ...
    ) -> None: ...
    def to_dict(self) -> V1beta1TokenRequestDict: ...

class V1beta1TokenRequestDict(typing.TypedDict, total=False):
    audience: str
    expirationSeconds: typing.Optional[int]



import datetime
import typing

import kubernetes.client

class V2beta1PodsMetricSource:
    metric_name: str
    selector: typing.Optional[kubernetes.client.V1LabelSelector]
    target_average_value: str
    def __init__(
        self,
        *,
        metric_name: str,
        selector: typing.Optional[kubernetes.client.V1LabelSelector] = ...,
        target_average_value: str
    ) -> None: ...
    def to_dict(self) -> V2beta1PodsMetricSourceDict: ...

class V2beta1PodsMetricSourceDict(typing.TypedDict, total=False):
    metricName: str
    selector: typing.Optional[kubernetes.client.V1LabelSelectorDict]
    targetAverageValue: str



import datetime
import typing

import kubernetes.client

class V1CustomResourceDefinitionSpec:
    conversion: typing.Optional[kubernetes.client.V1CustomResourceConversion]
    group: str
    names: kubernetes.client.V1CustomResourceDefinitionNames
    preserve_unknown_fields: typing.Optional[bool]
    scope: str
    versions: list[kubernetes.client.V1CustomResourceDefinitionVersion]
    def __init__(
        self,
        *,
        conversion: typing.Optional[kubernetes.client.V1CustomResourceConversion] = ...,
        group: str,
        names: kubernetes.client.V1CustomResourceDefinitionNames,
        preserve_unknown_fields: typing.Optional[bool] = ...,
        scope: str,
        versions: list[kubernetes.client.V1CustomResourceDefinitionVersion]
    ) -> None: ...
    def to_dict(self) -> V1CustomResourceDefinitionSpecDict: ...

class V1CustomResourceDefinitionSpecDict(typing.TypedDict, total=False):
    conversion: typing.Optional[kubernetes.client.V1CustomResourceConversionDict]
    group: str
    names: kubernetes.client.V1CustomResourceDefinitionNamesDict
    preserveUnknownFields: typing.Optional[bool]
    scope: str
    versions: list[kubernetes.client.V1CustomResourceDefinitionVersionDict]



import datetime
import typing

import kubernetes.client

class V1Probe:
    exec: typing.Optional[kubernetes.client.V1ExecAction]
    failure_threshold: typing.Optional[int]
    http_get: typing.Optional[kubernetes.client.V1HTTPGetAction]
    initial_delay_seconds: typing.Optional[int]
    period_seconds: typing.Optional[int]
    success_threshold: typing.Optional[int]
    tcp_socket: typing.Optional[kubernetes.client.V1TCPSocketAction]
    timeout_seconds: typing.Optional[int]
    def __init__(
        self,
        *,
        exec: typing.Optional[kubernetes.client.V1ExecAction] = ...,
        failure_threshold: typing.Optional[int] = ...,
        http_get: typing.Optional[kubernetes.client.V1HTTPGetAction] = ...,
        initial_delay_seconds: typing.Optional[int] = ...,
        period_seconds: typing.Optional[int] = ...,
        success_threshold: typing.Optional[int] = ...,
        tcp_socket: typing.Optional[kubernetes.client.V1TCPSocketAction] = ...,
        timeout_seconds: typing.Optional[int] = ...
    ) -> None: ...
    def to_dict(self) -> V1ProbeDict: ...

class V1ProbeDict(typing.TypedDict, total=False):
    exec: typing.Optional[kubernetes.client.V1ExecActionDict]
    failureThreshold: typing.Optional[int]
    httpGet: typing.Optional[kubernetes.client.V1HTTPGetActionDict]
    initialDelaySeconds: typing.Optional[int]
    periodSeconds: typing.Optional[int]
    successThreshold: typing.Optional[int]
    tcpSocket: typing.Optional[kubernetes.client.V1TCPSocketActionDict]
    timeoutSeconds: typing.Optional[int]



import datetime
import typing

import kubernetes.client

class V1DeleteOptions:
    api_version: typing.Optional[str]
    dry_run: typing.Optional[list[str]]
    grace_period_seconds: typing.Optional[int]
    kind: typing.Optional[str]
    orphan_dependents: typing.Optional[bool]
    preconditions: typing.Optional[kubernetes.client.V1Preconditions]
    propagation_policy: typing.Optional[str]
    def __init__(
        self,
        *,
        api_version: typing.Optional[str] = ...,
        dry_run: typing.Optional[list[str]] = ...,
        grace_period_seconds: typing.Optional[int] = ...,
        kind: typing.Optional[str] = ...,
        orphan_dependents: typing.Optional[bool] = ...,
        preconditions: typing.Optional[kubernetes.client.V1Preconditions] = ...,
        propagation_policy: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1DeleteOptionsDict: ...

class V1DeleteOptionsDict(typing.TypedDict, total=False):
    apiVersion: typing.Optional[str]
    dryRun: typing.Optional[list[str]]
    gracePeriodSeconds: typing.Optional[int]
    kind: typing.Optional[str]
    orphanDependents: typing.Optional[bool]
    preconditions: typing.Optional[kubernetes.client.V1PreconditionsDict]
    propagationPolicy: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1beta1CSINodeSpec:
    drivers: list[kubernetes.client.V1beta1CSINodeDriver]
    def __init__(
        self, *, drivers: list[kubernetes.client.V1beta1CSINodeDriver]
    ) -> None: ...
    def to_dict(self) -> V1beta1CSINodeSpecDict: ...

class V1beta1CSINodeSpecDict(typing.TypedDict, total=False):
    drivers: list[kubernetes.client.V1beta1CSINodeDriverDict]



import datetime
import typing

import kubernetes.client

class V1HorizontalPodAutoscalerStatus:
    current_cpu_utilization_percentage: typing.Optional[int]
    current_replicas: int
    desired_replicas: int
    last_scale_time: typing.Optional[datetime.datetime]
    observed_generation: typing.Optional[int]
    def __init__(
        self,
        *,
        current_cpu_utilization_percentage: typing.Optional[int] = ...,
        current_replicas: int,
        desired_replicas: int,
        last_scale_time: typing.Optional[datetime.datetime] = ...,
        observed_generation: typing.Optional[int] = ...
    ) -> None: ...
    def to_dict(self) -> V1HorizontalPodAutoscalerStatusDict: ...

class V1HorizontalPodAutoscalerStatusDict(typing.TypedDict, total=False):
    currentCPUUtilizationPercentage: typing.Optional[int]
    currentReplicas: int
    desiredReplicas: int
    lastScaleTime: typing.Optional[datetime.datetime]
    observedGeneration: typing.Optional[int]



import datetime
import typing

import kubernetes.client

class V1SubjectAccessReviewSpec:
    extra: typing.Optional[dict[str, list[str]]]
    groups: typing.Optional[list[str]]
    non_resource_attributes: typing.Optional[kubernetes.client.V1NonResourceAttributes]
    resource_attributes: typing.Optional[kubernetes.client.V1ResourceAttributes]
    uid: typing.Optional[str]
    user: typing.Optional[str]
    def __init__(
        self,
        *,
        extra: typing.Optional[dict[str, list[str]]] = ...,
        groups: typing.Optional[list[str]] = ...,
        non_resource_attributes: typing.Optional[
            kubernetes.client.V1NonResourceAttributes
        ] = ...,
        resource_attributes: typing.Optional[
            kubernetes.client.V1ResourceAttributes
        ] = ...,
        uid: typing.Optional[str] = ...,
        user: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1SubjectAccessReviewSpecDict: ...

class V1SubjectAccessReviewSpecDict(typing.TypedDict, total=False):
    extra: typing.Optional[dict[str, list[str]]]
    groups: typing.Optional[list[str]]
    nonResourceAttributes: typing.Optional[
        kubernetes.client.V1NonResourceAttributesDict
    ]
    resourceAttributes: typing.Optional[kubernetes.client.V1ResourceAttributesDict]
    uid: typing.Optional[str]
    user: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1Status:
    api_version: typing.Optional[str]
    code: typing.Optional[int]
    details: typing.Optional[kubernetes.client.V1StatusDetails]
    kind: typing.Optional[str]
    message: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ListMeta]
    reason: typing.Optional[str]
    status: typing.Optional[str]
    def __init__(
        self,
        *,
        api_version: typing.Optional[str] = ...,
        code: typing.Optional[int] = ...,
        details: typing.Optional[kubernetes.client.V1StatusDetails] = ...,
        kind: typing.Optional[str] = ...,
        message: typing.Optional[str] = ...,
        metadata: typing.Optional[kubernetes.client.V1ListMeta] = ...,
        reason: typing.Optional[str] = ...,
        status: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1StatusDict: ...

class V1StatusDict(typing.TypedDict, total=False):
    apiVersion: typing.Optional[str]
    code: typing.Optional[int]
    details: typing.Optional[kubernetes.client.V1StatusDetailsDict]
    kind: typing.Optional[str]
    message: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ListMetaDict]
    reason: typing.Optional[str]
    status: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1beta1ClusterRole:
    aggregation_rule: typing.Optional[kubernetes.client.V1beta1AggregationRule]
    api_version: typing.Optional[str]
    kind: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ObjectMeta]
    rules: typing.Optional[list[kubernetes.client.V1beta1PolicyRule]]
    def __init__(
        self,
        *,
        aggregation_rule: typing.Optional[
            kubernetes.client.V1beta1AggregationRule
        ] = ...,
        api_version: typing.Optional[str] = ...,
        kind: typing.Optional[str] = ...,
        metadata: typing.Optional[kubernetes.client.V1ObjectMeta] = ...,
        rules: typing.Optional[list[kubernetes.client.V1beta1PolicyRule]] = ...
    ) -> None: ...
    def to_dict(self) -> V1beta1ClusterRoleDict: ...

class V1beta1ClusterRoleDict(typing.TypedDict, total=False):
    aggregationRule: typing.Optional[kubernetes.client.V1beta1AggregationRuleDict]
    apiVersion: typing.Optional[str]
    kind: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ObjectMetaDict]
    rules: typing.Optional[list[kubernetes.client.V1beta1PolicyRuleDict]]



import datetime
import typing

import kubernetes.client

class V1beta1QueuingConfiguration:
    hand_size: typing.Optional[int]
    queue_length_limit: typing.Optional[int]
    queues: typing.Optional[int]
    def __init__(
        self,
        *,
        hand_size: typing.Optional[int] = ...,
        queue_length_limit: typing.Optional[int] = ...,
        queues: typing.Optional[int] = ...
    ) -> None: ...
    def to_dict(self) -> V1beta1QueuingConfigurationDict: ...

class V1beta1QueuingConfigurationDict(typing.TypedDict, total=False):
    handSize: typing.Optional[int]
    queueLengthLimit: typing.Optional[int]
    queues: typing.Optional[int]



import datetime
import typing

import kubernetes.client

class V1GlusterfsVolumeSource:
    endpoints: str
    path: str
    read_only: typing.Optional[bool]
    def __init__(
        self, *, endpoints: str, path: str, read_only: typing.Optional[bool] = ...
    ) -> None: ...
    def to_dict(self) -> V1GlusterfsVolumeSourceDict: ...

class V1GlusterfsVolumeSourceDict(typing.TypedDict, total=False):
    endpoints: str
    path: str
    readOnly: typing.Optional[bool]



import datetime
import typing

import kubernetes.client

class V1PodAntiAffinity:
    preferred_during_scheduling_ignored_during_execution: typing.Optional[
        list[kubernetes.client.V1WeightedPodAffinityTerm]
    ]
    required_during_scheduling_ignored_during_execution: typing.Optional[
        list[kubernetes.client.V1PodAffinityTerm]
    ]
    def __init__(
        self,
        *,
        preferred_during_scheduling_ignored_during_execution: typing.Optional[
            list[kubernetes.client.V1WeightedPodAffinityTerm]
        ] = ...,
        required_during_scheduling_ignored_during_execution: typing.Optional[
            list[kubernetes.client.V1PodAffinityTerm]
        ] = ...
    ) -> None: ...
    def to_dict(self) -> V1PodAntiAffinityDict: ...

class V1PodAntiAffinityDict(typing.TypedDict, total=False):
    preferredDuringSchedulingIgnoredDuringExecution: typing.Optional[
        list[kubernetes.client.V1WeightedPodAffinityTermDict]
    ]
    requiredDuringSchedulingIgnoredDuringExecution: typing.Optional[
        list[kubernetes.client.V1PodAffinityTermDict]
    ]



import datetime
import typing

import kubernetes.client

class V1VolumeNodeAffinity:
    required: typing.Optional[kubernetes.client.V1NodeSelector]
    def __init__(
        self, *, required: typing.Optional[kubernetes.client.V1NodeSelector] = ...
    ) -> None: ...
    def to_dict(self) -> V1VolumeNodeAffinityDict: ...

class V1VolumeNodeAffinityDict(typing.TypedDict, total=False):
    required: typing.Optional[kubernetes.client.V1NodeSelectorDict]



import datetime
import typing

import kubernetes.client

class V2beta2HorizontalPodAutoscalerSpec:
    behavior: typing.Optional[kubernetes.client.V2beta2HorizontalPodAutoscalerBehavior]
    max_replicas: int
    metrics: typing.Optional[list[kubernetes.client.V2beta2MetricSpec]]
    min_replicas: typing.Optional[int]
    scale_target_ref: kubernetes.client.V2beta2CrossVersionObjectReference
    def __init__(
        self,
        *,
        behavior: typing.Optional[
            kubernetes.client.V2beta2HorizontalPodAutoscalerBehavior
        ] = ...,
        max_replicas: int,
        metrics: typing.Optional[list[kubernetes.client.V2beta2MetricSpec]] = ...,
        min_replicas: typing.Optional[int] = ...,
        scale_target_ref: kubernetes.client.V2beta2CrossVersionObjectReference
    ) -> None: ...
    def to_dict(self) -> V2beta2HorizontalPodAutoscalerSpecDict: ...

class V2beta2HorizontalPodAutoscalerSpecDict(typing.TypedDict, total=False):
    behavior: typing.Optional[
        kubernetes.client.V2beta2HorizontalPodAutoscalerBehaviorDict
    ]
    maxReplicas: int
    metrics: typing.Optional[list[kubernetes.client.V2beta2MetricSpecDict]]
    minReplicas: typing.Optional[int]
    scaleTargetRef: kubernetes.client.V2beta2CrossVersionObjectReferenceDict



from typing import Optional

class Configuration(object):
    host: str
    temp_folder_path: str
    api_key: dict[str, str]
    api_key_prefix: str
    username: str
    password: str
    discard_unknown_keys: bool
    def __init__(
        self,
        host: str = ...,
        api_key: Optional[str] = ...,
        api_key_prefix: Optional[str] = ...,
        username: Optional[str] = ...,
        password: Optional[str] = ...,
        discard_unknown_keys: bool = ...,
    ) -> None: ...



import datetime
import typing

import kubernetes.client

class V1NetworkPolicyIngressRule:
    _from: typing.Optional[list[kubernetes.client.V1NetworkPolicyPeer]]
    ports: typing.Optional[list[kubernetes.client.V1NetworkPolicyPort]]
    def __init__(
        self,
        *,
        _from: typing.Optional[list[kubernetes.client.V1NetworkPolicyPeer]] = ...,
        ports: typing.Optional[list[kubernetes.client.V1NetworkPolicyPort]] = ...
    ) -> None: ...
    def to_dict(self) -> V1NetworkPolicyIngressRuleDict: ...

class V1NetworkPolicyIngressRuleDict(typing.TypedDict, total=False):
    _from: typing.Optional[list[kubernetes.client.V1NetworkPolicyPeerDict]]
    ports: typing.Optional[list[kubernetes.client.V1NetworkPolicyPortDict]]



import datetime
import typing

import kubernetes.client

class V2alpha1CronJobStatus:
    active: typing.Optional[list[kubernetes.client.V1ObjectReference]]
    last_schedule_time: typing.Optional[datetime.datetime]
    def __init__(
        self,
        *,
        active: typing.Optional[list[kubernetes.client.V1ObjectReference]] = ...,
        last_schedule_time: typing.Optional[datetime.datetime] = ...
    ) -> None: ...
    def to_dict(self) -> V2alpha1CronJobStatusDict: ...

class V2alpha1CronJobStatusDict(typing.TypedDict, total=False):
    active: typing.Optional[list[kubernetes.client.V1ObjectReferenceDict]]
    lastScheduleTime: typing.Optional[datetime.datetime]



import datetime
import typing

import kubernetes.client

class V1beta1SelfSubjectAccessReview:
    api_version: typing.Optional[str]
    kind: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ObjectMeta]
    spec: kubernetes.client.V1beta1SelfSubjectAccessReviewSpec
    status: typing.Optional[kubernetes.client.V1beta1SubjectAccessReviewStatus]
    def __init__(
        self,
        *,
        api_version: typing.Optional[str] = ...,
        kind: typing.Optional[str] = ...,
        metadata: typing.Optional[kubernetes.client.V1ObjectMeta] = ...,
        spec: kubernetes.client.V1beta1SelfSubjectAccessReviewSpec,
        status: typing.Optional[
            kubernetes.client.V1beta1SubjectAccessReviewStatus
        ] = ...
    ) -> None: ...
    def to_dict(self) -> V1beta1SelfSubjectAccessReviewDict: ...

class V1beta1SelfSubjectAccessReviewDict(typing.TypedDict, total=False):
    apiVersion: typing.Optional[str]
    kind: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ObjectMetaDict]
    spec: kubernetes.client.V1beta1SelfSubjectAccessReviewSpecDict
    status: typing.Optional[kubernetes.client.V1beta1SubjectAccessReviewStatusDict]



from typing import Any, Callable, TypeVar

T = TypeVar("T")

def stream(fn: Callable[..., T], *args: Any, **kwargs: Any) -> T: ...
def portforward(fn: Callable[..., T], *args: Any, **kwargs: Any) -> T: ...



import datetime
import typing

import kubernetes.client

class V1TokenReviewSpec:
    audiences: typing.Optional[list[str]]
    token: typing.Optional[str]
    def __init__(
        self,
        *,
        audiences: typing.Optional[list[str]] = ...,
        token: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1TokenReviewSpecDict: ...

class V1TokenReviewSpecDict(typing.TypedDict, total=False):
    audiences: typing.Optional[list[str]]
    token: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1VsphereVirtualDiskVolumeSource:
    fs_type: typing.Optional[str]
    storage_policy_id: typing.Optional[str]
    storage_policy_name: typing.Optional[str]
    volume_path: str
    def __init__(
        self,
        *,
        fs_type: typing.Optional[str] = ...,
        storage_policy_id: typing.Optional[str] = ...,
        storage_policy_name: typing.Optional[str] = ...,
        volume_path: str
    ) -> None: ...
    def to_dict(self) -> V1VsphereVirtualDiskVolumeSourceDict: ...

class V1VsphereVirtualDiskVolumeSourceDict(typing.TypedDict, total=False):
    fsType: typing.Optional[str]
    storagePolicyID: typing.Optional[str]
    storagePolicyName: typing.Optional[str]
    volumePath: str



import datetime
import typing

import kubernetes.client

class V1CSIVolumeSource:
    driver: str
    fs_type: typing.Optional[str]
    node_publish_secret_ref: typing.Optional[kubernetes.client.V1LocalObjectReference]
    read_only: typing.Optional[bool]
    volume_attributes: typing.Optional[dict[str, str]]
    def __init__(
        self,
        *,
        driver: str,
        fs_type: typing.Optional[str] = ...,
        node_publish_secret_ref: typing.Optional[
            kubernetes.client.V1LocalObjectReference
        ] = ...,
        read_only: typing.Optional[bool] = ...,
        volume_attributes: typing.Optional[dict[str, str]] = ...
    ) -> None: ...
    def to_dict(self) -> V1CSIVolumeSourceDict: ...

class V1CSIVolumeSourceDict(typing.TypedDict, total=False):
    driver: str
    fsType: typing.Optional[str]
    nodePublishSecretRef: typing.Optional[kubernetes.client.V1LocalObjectReferenceDict]
    readOnly: typing.Optional[bool]
    volumeAttributes: typing.Optional[dict[str, str]]



import datetime
import typing

import kubernetes.client

class V2beta2CrossVersionObjectReference:
    api_version: typing.Optional[str]
    kind: str
    name: str
    def __init__(
        self, *, api_version: typing.Optional[str] = ..., kind: str, name: str
    ) -> None: ...
    def to_dict(self) -> V2beta2CrossVersionObjectReferenceDict: ...

class V2beta2CrossVersionObjectReferenceDict(typing.TypedDict, total=False):
    apiVersion: typing.Optional[str]
    kind: str
    name: str



import datetime
import typing

import kubernetes.client

class V1DownwardAPIVolumeFile:
    field_ref: typing.Optional[kubernetes.client.V1ObjectFieldSelector]
    mode: typing.Optional[int]
    path: str
    resource_field_ref: typing.Optional[kubernetes.client.V1ResourceFieldSelector]
    def __init__(
        self,
        *,
        field_ref: typing.Optional[kubernetes.client.V1ObjectFieldSelector] = ...,
        mode: typing.Optional[int] = ...,
        path: str,
        resource_field_ref: typing.Optional[
            kubernetes.client.V1ResourceFieldSelector
        ] = ...
    ) -> None: ...
    def to_dict(self) -> V1DownwardAPIVolumeFileDict: ...

class V1DownwardAPIVolumeFileDict(typing.TypedDict, total=False):
    fieldRef: typing.Optional[kubernetes.client.V1ObjectFieldSelectorDict]
    mode: typing.Optional[int]
    path: str
    resourceFieldRef: typing.Optional[kubernetes.client.V1ResourceFieldSelectorDict]



from typing import Any, Optional

from kubernetes.client.rest import RESTResponse

class OpenApiException(Exception): ...

class ApiTypeError(OpenApiException, TypeError):
    path_to_item: Optional[list[str]]
    valid_classes: Optional[tuple[Any, ...]]
    key_type: Optional[bool]
    def __init__(
        self,
        msg: str,
        path_to_item: Optional[list[str]] = ...,
        valid_classes: Optional[tuple[Any, ...]] = ...,
        key_type: Optional[bool] = ...,
    ) -> None: ...

class ApiValueError(OpenApiException, ValueError):
    path_to_item: Optional[list[Any]]
    def __init__(self, msg: str, path_to_item: Optional[list[Any]] = ...) -> None: ...

class ApiKeyError(OpenApiException, KeyError):
    path_to_item: Optional[list[Any]]
    def __init__(self, msg: str, path_to_item: Optional[list[Any]] = ...) -> None: ...

class ApiException(OpenApiException):
    status: Optional[int]
    reason: Optional[str]
    body: Optional[str]
    headers: dict[str, str]
    def __init__(
        self,
        status: Optional[int] = ...,
        reason: Optional[str] = ...,
        http_resp: Optional[RESTResponse] = ...,
    ) -> None: ...



import datetime
import typing

import kubernetes.client

class V1ResourceFieldSelector:
    container_name: typing.Optional[str]
    divisor: typing.Optional[str]
    resource: str
    def __init__(
        self,
        *,
        container_name: typing.Optional[str] = ...,
        divisor: typing.Optional[str] = ...,
        resource: str
    ) -> None: ...
    def to_dict(self) -> V1ResourceFieldSelectorDict: ...

class V1ResourceFieldSelectorDict(typing.TypedDict, total=False):
    containerName: typing.Optional[str]
    divisor: typing.Optional[str]
    resource: str



import datetime
import typing

import kubernetes.client

class V1NodeSelectorTerm:
    match_expressions: typing.Optional[
        list[kubernetes.client.V1NodeSelectorRequirement]
    ]
    match_fields: typing.Optional[list[kubernetes.client.V1NodeSelectorRequirement]]
    def __init__(
        self,
        *,
        match_expressions: typing.Optional[
            list[kubernetes.client.V1NodeSelectorRequirement]
        ] = ...,
        match_fields: typing.Optional[
            list[kubernetes.client.V1NodeSelectorRequirement]
        ] = ...
    ) -> None: ...
    def to_dict(self) -> V1NodeSelectorTermDict: ...

class V1NodeSelectorTermDict(typing.TypedDict, total=False):
    matchExpressions: typing.Optional[
        list[kubernetes.client.V1NodeSelectorRequirementDict]
    ]
    matchFields: typing.Optional[list[kubernetes.client.V1NodeSelectorRequirementDict]]



import datetime
import typing

import kubernetes.client

class ApiextensionsV1beta1ServiceReference:
    name: str
    namespace: str
    path: typing.Optional[str]
    port: typing.Optional[int]
    def __init__(
        self,
        *,
        name: str,
        namespace: str,
        path: typing.Optional[str] = ...,
        port: typing.Optional[int] = ...
    ) -> None: ...
    def to_dict(self) -> ApiextensionsV1beta1ServiceReferenceDict: ...

class ApiextensionsV1beta1ServiceReferenceDict(typing.TypedDict, total=False):
    name: str
    namespace: str
    path: typing.Optional[str]
    port: typing.Optional[int]



import datetime
import typing

import kubernetes.client

class V1CustomResourceConversion:
    strategy: str
    webhook: typing.Optional[kubernetes.client.V1WebhookConversion]
    def __init__(
        self,
        *,
        strategy: str,
        webhook: typing.Optional[kubernetes.client.V1WebhookConversion] = ...
    ) -> None: ...
    def to_dict(self) -> V1CustomResourceConversionDict: ...

class V1CustomResourceConversionDict(typing.TypedDict, total=False):
    strategy: str
    webhook: typing.Optional[kubernetes.client.V1WebhookConversionDict]



import datetime
import typing

import kubernetes.client

class FlowcontrolV1beta1Subject:
    group: typing.Optional[kubernetes.client.V1beta1GroupSubject]
    kind: str
    service_account: typing.Optional[kubernetes.client.V1beta1ServiceAccountSubject]
    user: typing.Optional[kubernetes.client.V1beta1UserSubject]
    def __init__(
        self,
        *,
        group: typing.Optional[kubernetes.client.V1beta1GroupSubject] = ...,
        kind: str,
        service_account: typing.Optional[
            kubernetes.client.V1beta1ServiceAccountSubject
        ] = ...,
        user: typing.Optional[kubernetes.client.V1beta1UserSubject] = ...
    ) -> None: ...
    def to_dict(self) -> FlowcontrolV1beta1SubjectDict: ...

class FlowcontrolV1beta1SubjectDict(typing.TypedDict, total=False):
    group: typing.Optional[kubernetes.client.V1beta1GroupSubjectDict]
    kind: str
    serviceAccount: typing.Optional[kubernetes.client.V1beta1ServiceAccountSubjectDict]
    user: typing.Optional[kubernetes.client.V1beta1UserSubjectDict]



import datetime
import typing

import kubernetes.client

class V1NetworkPolicyEgressRule:
    ports: typing.Optional[list[kubernetes.client.V1NetworkPolicyPort]]
    to: typing.Optional[list[kubernetes.client.V1NetworkPolicyPeer]]
    def __init__(
        self,
        *,
        ports: typing.Optional[list[kubernetes.client.V1NetworkPolicyPort]] = ...,
        to: typing.Optional[list[kubernetes.client.V1NetworkPolicyPeer]] = ...
    ) -> None: ...
    def to_dict(self) -> V1NetworkPolicyEgressRuleDict: ...

class V1NetworkPolicyEgressRuleDict(typing.TypedDict, total=False):
    ports: typing.Optional[list[kubernetes.client.V1NetworkPolicyPortDict]]
    to: typing.Optional[list[kubernetes.client.V1NetworkPolicyPeerDict]]



import datetime
import typing

import kubernetes.client

class V1HTTPGetAction:
    host: typing.Optional[str]
    http_headers: typing.Optional[list[kubernetes.client.V1HTTPHeader]]
    path: typing.Optional[str]
    port: typing.Any
    scheme: typing.Optional[str]
    def __init__(
        self,
        *,
        host: typing.Optional[str] = ...,
        http_headers: typing.Optional[list[kubernetes.client.V1HTTPHeader]] = ...,
        path: typing.Optional[str] = ...,
        port: typing.Any,
        scheme: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1HTTPGetActionDict: ...

class V1HTTPGetActionDict(typing.TypedDict, total=False):
    host: typing.Optional[str]
    httpHeaders: typing.Optional[list[kubernetes.client.V1HTTPHeaderDict]]
    path: typing.Optional[str]
    port: typing.Any
    scheme: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1EnvVar:
    name: str
    value: typing.Optional[str]
    value_from: typing.Optional[kubernetes.client.V1EnvVarSource]
    def __init__(
        self,
        *,
        name: str,
        value: typing.Optional[str] = ...,
        value_from: typing.Optional[kubernetes.client.V1EnvVarSource] = ...
    ) -> None: ...
    def to_dict(self) -> V1EnvVarDict: ...

class V1EnvVarDict(typing.TypedDict, total=False):
    name: str
    value: typing.Optional[str]
    valueFrom: typing.Optional[kubernetes.client.V1EnvVarSourceDict]



import datetime
import typing

import kubernetes.client

class V1WatchEvent:
    object: typing.Any
    type: str
    def __init__(self, *, object: typing.Any, type: str) -> None: ...
    def to_dict(self) -> V1WatchEventDict: ...

class V1WatchEventDict(typing.TypedDict, total=False):
    object: typing.Any
    type: str



import datetime
import typing

import kubernetes.client

class V1PodStatus:
    conditions: typing.Optional[list[kubernetes.client.V1PodCondition]]
    container_statuses: typing.Optional[list[kubernetes.client.V1ContainerStatus]]
    ephemeral_container_statuses: typing.Optional[
        list[kubernetes.client.V1ContainerStatus]
    ]
    host_ip: typing.Optional[str]
    init_container_statuses: typing.Optional[list[kubernetes.client.V1ContainerStatus]]
    message: typing.Optional[str]
    nominated_node_name: typing.Optional[str]
    phase: typing.Optional[str]
    pod_ip: typing.Optional[str]
    pod_i_ps: typing.Optional[list[kubernetes.client.V1PodIP]]
    qos_class: typing.Optional[str]
    reason: typing.Optional[str]
    start_time: typing.Optional[datetime.datetime]
    def __init__(
        self,
        *,
        conditions: typing.Optional[list[kubernetes.client.V1PodCondition]] = ...,
        container_statuses: typing.Optional[
            list[kubernetes.client.V1ContainerStatus]
        ] = ...,
        ephemeral_container_statuses: typing.Optional[
            list[kubernetes.client.V1ContainerStatus]
        ] = ...,
        host_ip: typing.Optional[str] = ...,
        init_container_statuses: typing.Optional[
            list[kubernetes.client.V1ContainerStatus]
        ] = ...,
        message: typing.Optional[str] = ...,
        nominated_node_name: typing.Optional[str] = ...,
        phase: typing.Optional[str] = ...,
        pod_ip: typing.Optional[str] = ...,
        pod_i_ps: typing.Optional[list[kubernetes.client.V1PodIP]] = ...,
        qos_class: typing.Optional[str] = ...,
        reason: typing.Optional[str] = ...,
        start_time: typing.Optional[datetime.datetime] = ...
    ) -> None: ...
    def to_dict(self) -> V1PodStatusDict: ...

class V1PodStatusDict(typing.TypedDict, total=False):
    conditions: typing.Optional[list[kubernetes.client.V1PodConditionDict]]
    containerStatuses: typing.Optional[list[kubernetes.client.V1ContainerStatusDict]]
    ephemeralContainerStatuses: typing.Optional[
        list[kubernetes.client.V1ContainerStatusDict]
    ]
    hostIP: typing.Optional[str]
    initContainerStatuses: typing.Optional[
        list[kubernetes.client.V1ContainerStatusDict]
    ]
    message: typing.Optional[str]
    nominatedNodeName: typing.Optional[str]
    phase: typing.Optional[str]
    podIP: typing.Optional[str]
    podIPs: typing.Optional[list[kubernetes.client.V1PodIPDict]]
    qosClass: typing.Optional[str]
    reason: typing.Optional[str]
    startTime: typing.Optional[datetime.datetime]



from typing import Any, Optional, TypedDict

from kubernetes.client import ApiClient, Configuration

KUBE_CONFIG_DEFAULT_LOCATION: str = ...

class Context(TypedDict):
    name: str
    context: dict[str, Any]

def list_kube_config_contexts(
    config_file: Optional[str] = ...,
) -> tuple[list[Context], Context]: ...
def load_kube_config(
    config_file: Optional[str] = ...,
    context: Optional[str] = ...,
    client_configuration: Optional[Configuration] = ...,
    persist_config: bool = ...,
) -> None: ...
def load_kube_config_from_dict(
    config_dict: dict[Any, Any] = ...,
    context: Optional[str] = ...,
    client_configuration: Optional[Configuration] = ...,
    persist_config: bool = ...,
    temp_file_path: Optional[str] = ...,
) -> None: ...
def new_client_from_config(
    config_file: Optional[str] = ...,
    context: Optional[str] = ...,
    persist_config: bool = ...,
) -> ApiClient: ...



import datetime
import typing

import kubernetes.client

class V1HorizontalPodAutoscalerSpec:
    max_replicas: int
    min_replicas: typing.Optional[int]
    scale_target_ref: kubernetes.client.V1CrossVersionObjectReference
    target_cpu_utilization_percentage: typing.Optional[int]
    def __init__(
        self,
        *,
        max_replicas: int,
        min_replicas: typing.Optional[int] = ...,
        scale_target_ref: kubernetes.client.V1CrossVersionObjectReference,
        target_cpu_utilization_percentage: typing.Optional[int] = ...
    ) -> None: ...
    def to_dict(self) -> V1HorizontalPodAutoscalerSpecDict: ...

class V1HorizontalPodAutoscalerSpecDict(typing.TypedDict, total=False):
    maxReplicas: int
    minReplicas: typing.Optional[int]
    scaleTargetRef: kubernetes.client.V1CrossVersionObjectReferenceDict
    targetCPUUtilizationPercentage: typing.Optional[int]



import datetime
import typing

import kubernetes.client

class V1NonResourceAttributes:
    path: typing.Optional[str]
    verb: typing.Optional[str]
    def __init__(
        self, *, path: typing.Optional[str] = ..., verb: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1NonResourceAttributesDict: ...

class V1NonResourceAttributesDict(typing.TypedDict, total=False):
    path: typing.Optional[str]
    verb: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1ExecAction:
    command: typing.Optional[list[str]]
    def __init__(self, *, command: typing.Optional[list[str]] = ...) -> None: ...
    def to_dict(self) -> V1ExecActionDict: ...

class V1ExecActionDict(typing.TypedDict, total=False):
    command: typing.Optional[list[str]]



import datetime
import typing

import kubernetes.client

class V1alpha1FlowSchemaStatus:
    conditions: typing.Optional[list[kubernetes.client.V1alpha1FlowSchemaCondition]]
    def __init__(
        self,
        *,
        conditions: typing.Optional[
            list[kubernetes.client.V1alpha1FlowSchemaCondition]
        ] = ...
    ) -> None: ...
    def to_dict(self) -> V1alpha1FlowSchemaStatusDict: ...

class V1alpha1FlowSchemaStatusDict(typing.TypedDict, total=False):
    conditions: typing.Optional[list[kubernetes.client.V1alpha1FlowSchemaConditionDict]]



import datetime
import typing

import kubernetes.client

class V1beta1IDRange:
    max: int
    min: int
    def __init__(self, *, max: int, min: int) -> None: ...
    def to_dict(self) -> V1beta1IDRangeDict: ...

class V1beta1IDRangeDict(typing.TypedDict, total=False):
    max: int
    min: int



import datetime
import typing

import kubernetes.client

class V1NetworkPolicySpec:
    egress: typing.Optional[list[kubernetes.client.V1NetworkPolicyEgressRule]]
    ingress: typing.Optional[list[kubernetes.client.V1NetworkPolicyIngressRule]]
    pod_selector: kubernetes.client.V1LabelSelector
    policy_types: typing.Optional[list[str]]
    def __init__(
        self,
        *,
        egress: typing.Optional[
            list[kubernetes.client.V1NetworkPolicyEgressRule]
        ] = ...,
        ingress: typing.Optional[
            list[kubernetes.client.V1NetworkPolicyIngressRule]
        ] = ...,
        pod_selector: kubernetes.client.V1LabelSelector,
        policy_types: typing.Optional[list[str]] = ...
    ) -> None: ...
    def to_dict(self) -> V1NetworkPolicySpecDict: ...

class V1NetworkPolicySpecDict(typing.TypedDict, total=False):
    egress: typing.Optional[list[kubernetes.client.V1NetworkPolicyEgressRuleDict]]
    ingress: typing.Optional[list[kubernetes.client.V1NetworkPolicyIngressRuleDict]]
    podSelector: kubernetes.client.V1LabelSelectorDict
    policyTypes: typing.Optional[list[str]]



import datetime
import typing

import kubernetes.client

class V1ListMeta:
    _continue: typing.Optional[str]
    remaining_item_count: typing.Optional[int]
    resource_version: typing.Optional[str]
    self_link: typing.Optional[str]
    def __init__(
        self,
        *,
        _continue: typing.Optional[str] = ...,
        remaining_item_count: typing.Optional[int] = ...,
        resource_version: typing.Optional[str] = ...,
        self_link: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1ListMetaDict: ...

class V1ListMetaDict(typing.TypedDict, total=False):
    _continue: typing.Optional[str]
    remainingItemCount: typing.Optional[int]
    resourceVersion: typing.Optional[str]
    selfLink: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V2beta2ExternalMetricSource:
    metric: kubernetes.client.V2beta2MetricIdentifier
    target: kubernetes.client.V2beta2MetricTarget
    def __init__(
        self,
        *,
        metric: kubernetes.client.V2beta2MetricIdentifier,
        target: kubernetes.client.V2beta2MetricTarget
    ) -> None: ...
    def to_dict(self) -> V2beta2ExternalMetricSourceDict: ...

class V2beta2ExternalMetricSourceDict(typing.TypedDict, total=False):
    metric: kubernetes.client.V2beta2MetricIdentifierDict
    target: kubernetes.client.V2beta2MetricTargetDict



import datetime
import typing

import kubernetes.client

class V1PodDNSConfigOption:
    name: typing.Optional[str]
    value: typing.Optional[str]
    def __init__(
        self, *, name: typing.Optional[str] = ..., value: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1PodDNSConfigOptionDict: ...

class V1PodDNSConfigOptionDict(typing.TypedDict, total=False):
    name: typing.Optional[str]
    value: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V2beta2HorizontalPodAutoscalerBehavior:
    scale_down: typing.Optional[kubernetes.client.V2beta2HPAScalingRules]
    scale_up: typing.Optional[kubernetes.client.V2beta2HPAScalingRules]
    def __init__(
        self,
        *,
        scale_down: typing.Optional[kubernetes.client.V2beta2HPAScalingRules] = ...,
        scale_up: typing.Optional[kubernetes.client.V2beta2HPAScalingRules] = ...
    ) -> None: ...
    def to_dict(self) -> V2beta2HorizontalPodAutoscalerBehaviorDict: ...

class V2beta2HorizontalPodAutoscalerBehaviorDict(typing.TypedDict, total=False):
    scaleDown: typing.Optional[kubernetes.client.V2beta2HPAScalingRulesDict]
    scaleUp: typing.Optional[kubernetes.client.V2beta2HPAScalingRulesDict]



import datetime
import typing

import kubernetes.client

class V1ServiceStatus:
    conditions: typing.Optional[list[kubernetes.client.V1Condition]]
    load_balancer: typing.Optional[kubernetes.client.V1LoadBalancerStatus]
    def __init__(
        self,
        *,
        conditions: typing.Optional[list[kubernetes.client.V1Condition]] = ...,
        load_balancer: typing.Optional[kubernetes.client.V1LoadBalancerStatus] = ...
    ) -> None: ...
    def to_dict(self) -> V1ServiceStatusDict: ...

class V1ServiceStatusDict(typing.TypedDict, total=False):
    conditions: typing.Optional[list[kubernetes.client.V1ConditionDict]]
    loadBalancer: typing.Optional[kubernetes.client.V1LoadBalancerStatusDict]



import datetime
import typing

import kubernetes.client

class V1ServerAddressByClientCIDR:
    client_cidr: str
    server_address: str
    def __init__(self, *, client_cidr: str, server_address: str) -> None: ...
    def to_dict(self) -> V1ServerAddressByClientCIDRDict: ...

class V1ServerAddressByClientCIDRDict(typing.TypedDict, total=False):
    clientCIDR: str
    serverAddress: str



import datetime
import typing

import kubernetes.client

class V1ConfigMapNodeConfigSource:
    kubelet_config_key: str
    name: str
    namespace: str
    resource_version: typing.Optional[str]
    uid: typing.Optional[str]
    def __init__(
        self,
        *,
        kubelet_config_key: str,
        name: str,
        namespace: str,
        resource_version: typing.Optional[str] = ...,
        uid: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1ConfigMapNodeConfigSourceDict: ...

class V1ConfigMapNodeConfigSourceDict(typing.TypedDict, total=False):
    kubeletConfigKey: str
    name: str
    namespace: str
    resourceVersion: typing.Optional[str]
    uid: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1TokenRequestSpec:
    audiences: list[str]
    bound_object_ref: typing.Optional[kubernetes.client.V1BoundObjectReference]
    expiration_seconds: typing.Optional[int]
    def __init__(
        self,
        *,
        audiences: list[str],
        bound_object_ref: typing.Optional[
            kubernetes.client.V1BoundObjectReference
        ] = ...,
        expiration_seconds: typing.Optional[int] = ...
    ) -> None: ...
    def to_dict(self) -> V1TokenRequestSpecDict: ...

class V1TokenRequestSpecDict(typing.TypedDict, total=False):
    audiences: list[str]
    boundObjectRef: typing.Optional[kubernetes.client.V1BoundObjectReferenceDict]
    expirationSeconds: typing.Optional[int]



import datetime
import typing

import kubernetes.client

class V1ControllerRevision:
    api_version: typing.Optional[str]
    data: typing.Optional[typing.Any]
    kind: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ObjectMeta]
    revision: int
    def __init__(
        self,
        *,
        api_version: typing.Optional[str] = ...,
        data: typing.Optional[typing.Any] = ...,
        kind: typing.Optional[str] = ...,
        metadata: typing.Optional[kubernetes.client.V1ObjectMeta] = ...,
        revision: int
    ) -> None: ...
    def to_dict(self) -> V1ControllerRevisionDict: ...

class V1ControllerRevisionDict(typing.TypedDict, total=False):
    apiVersion: typing.Optional[str]
    data: typing.Optional[typing.Any]
    kind: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ObjectMetaDict]
    revision: int



import datetime
import typing

import kubernetes.client

class V1PodSecurityContext:
    fs_group: typing.Optional[int]
    fs_group_change_policy: typing.Optional[str]
    run_as_group: typing.Optional[int]
    run_as_non_root: typing.Optional[bool]
    run_as_user: typing.Optional[int]
    se_linux_options: typing.Optional[kubernetes.client.V1SELinuxOptions]
    seccomp_profile: typing.Optional[kubernetes.client.V1SeccompProfile]
    supplemental_groups: typing.Optional[list[int]]
    sysctls: typing.Optional[list[kubernetes.client.V1Sysctl]]
    windows_options: typing.Optional[kubernetes.client.V1WindowsSecurityContextOptions]
    def __init__(
        self,
        *,
        fs_group: typing.Optional[int] = ...,
        fs_group_change_policy: typing.Optional[str] = ...,
        run_as_group: typing.Optional[int] = ...,
        run_as_non_root: typing.Optional[bool] = ...,
        run_as_user: typing.Optional[int] = ...,
        se_linux_options: typing.Optional[kubernetes.client.V1SELinuxOptions] = ...,
        seccomp_profile: typing.Optional[kubernetes.client.V1SeccompProfile] = ...,
        supplemental_groups: typing.Optional[list[int]] = ...,
        sysctls: typing.Optional[list[kubernetes.client.V1Sysctl]] = ...,
        windows_options: typing.Optional[
            kubernetes.client.V1WindowsSecurityContextOptions
        ] = ...
    ) -> None: ...
    def to_dict(self) -> V1PodSecurityContextDict: ...

class V1PodSecurityContextDict(typing.TypedDict, total=False):
    fsGroup: typing.Optional[int]
    fsGroupChangePolicy: typing.Optional[str]
    runAsGroup: typing.Optional[int]
    runAsNonRoot: typing.Optional[bool]
    runAsUser: typing.Optional[int]
    seLinuxOptions: typing.Optional[kubernetes.client.V1SELinuxOptionsDict]
    seccompProfile: typing.Optional[kubernetes.client.V1SeccompProfileDict]
    supplementalGroups: typing.Optional[list[int]]
    sysctls: typing.Optional[list[kubernetes.client.V1SysctlDict]]
    windowsOptions: typing.Optional[
        kubernetes.client.V1WindowsSecurityContextOptionsDict
    ]



import typing

import kubernetes.client

class WellKnownApi:
    def __init__(
        self, api_client: typing.Optional[kubernetes.client.ApiClient] = ...
    ) -> None: ...
    def get_service_account_issuer_open_id_configuration(self) -> str: ...



import datetime
import typing

import kubernetes.client

class V1BoundObjectReference:
    api_version: typing.Optional[str]
    kind: typing.Optional[str]
    name: typing.Optional[str]
    uid: typing.Optional[str]
    def __init__(
        self,
        *,
        api_version: typing.Optional[str] = ...,
        kind: typing.Optional[str] = ...,
        name: typing.Optional[str] = ...,
        uid: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1BoundObjectReferenceDict: ...

class V1BoundObjectReferenceDict(typing.TypedDict, total=False):
    apiVersion: typing.Optional[str]
    kind: typing.Optional[str]
    name: typing.Optional[str]
    uid: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V2alpha1CronJob:
    api_version: typing.Optional[str]
    kind: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ObjectMeta]
    spec: typing.Optional[kubernetes.client.V2alpha1CronJobSpec]
    status: typing.Optional[kubernetes.client.V2alpha1CronJobStatus]
    def __init__(
        self,
        *,
        api_version: typing.Optional[str] = ...,
        kind: typing.Optional[str] = ...,
        metadata: typing.Optional[kubernetes.client.V1ObjectMeta] = ...,
        spec: typing.Optional[kubernetes.client.V2alpha1CronJobSpec] = ...,
        status: typing.Optional[kubernetes.client.V2alpha1CronJobStatus] = ...
    ) -> None: ...
    def to_dict(self) -> V2alpha1CronJobDict: ...

class V2alpha1CronJobDict(typing.TypedDict, total=False):
    apiVersion: typing.Optional[str]
    kind: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ObjectMetaDict]
    spec: typing.Optional[kubernetes.client.V2alpha1CronJobSpecDict]
    status: typing.Optional[kubernetes.client.V2alpha1CronJobStatusDict]



import datetime
import typing

import kubernetes.client

class V2beta1ExternalMetricStatus:
    current_average_value: typing.Optional[str]
    current_value: str
    metric_name: str
    metric_selector: typing.Optional[kubernetes.client.V1LabelSelector]
    def __init__(
        self,
        *,
        current_average_value: typing.Optional[str] = ...,
        current_value: str,
        metric_name: str,
        metric_selector: typing.Optional[kubernetes.client.V1LabelSelector] = ...
    ) -> None: ...
    def to_dict(self) -> V2beta1ExternalMetricStatusDict: ...

class V2beta1ExternalMetricStatusDict(typing.TypedDict, total=False):
    currentAverageValue: typing.Optional[str]
    currentValue: str
    metricName: str
    metricSelector: typing.Optional[kubernetes.client.V1LabelSelectorDict]



import datetime
import typing

import kubernetes.client

class V1SelfSubjectAccessReviewSpec:
    non_resource_attributes: typing.Optional[kubernetes.client.V1NonResourceAttributes]
    resource_attributes: typing.Optional[kubernetes.client.V1ResourceAttributes]
    def __init__(
        self,
        *,
        non_resource_attributes: typing.Optional[
            kubernetes.client.V1NonResourceAttributes
        ] = ...,
        resource_attributes: typing.Optional[
            kubernetes.client.V1ResourceAttributes
        ] = ...
    ) -> None: ...
    def to_dict(self) -> V1SelfSubjectAccessReviewSpecDict: ...

class V1SelfSubjectAccessReviewSpecDict(typing.TypedDict, total=False):
    nonResourceAttributes: typing.Optional[
        kubernetes.client.V1NonResourceAttributesDict
    ]
    resourceAttributes: typing.Optional[kubernetes.client.V1ResourceAttributesDict]



from typing import Optional

from kubernetes.client import Configuration

def load_incluster_config(
    client_configuration: Optional[Configuration] = ..., try_refresh_token: bool = ...
) -> None: ...



import datetime
import typing

import kubernetes.client

class V1beta1CSINodeDriver:
    allocatable: typing.Optional[kubernetes.client.V1beta1VolumeNodeResources]
    name: str
    node_id: str
    topology_keys: typing.Optional[list[str]]
    def __init__(
        self,
        *,
        allocatable: typing.Optional[
            kubernetes.client.V1beta1VolumeNodeResources
        ] = ...,
        name: str,
        node_id: str,
        topology_keys: typing.Optional[list[str]] = ...
    ) -> None: ...
    def to_dict(self) -> V1beta1CSINodeDriverDict: ...

class V1beta1CSINodeDriverDict(typing.TypedDict, total=False):
    allocatable: typing.Optional[kubernetes.client.V1beta1VolumeNodeResourcesDict]
    name: str
    nodeID: str
    topologyKeys: typing.Optional[list[str]]



import datetime
import typing

import kubernetes.client

class V1TokenRequestStatus:
    expiration_timestamp: datetime.datetime
    token: str
    def __init__(
        self, *, expiration_timestamp: datetime.datetime, token: str
    ) -> None: ...
    def to_dict(self) -> V1TokenRequestStatusDict: ...

class V1TokenRequestStatusDict(typing.TypedDict, total=False):
    expirationTimestamp: datetime.datetime
    token: str



from typing import Any, Optional, Protocol, Type, TypeVar

from kubernetes.client import Configuration

_T = TypeVar("_T")

class Response(Protocol):
    data: str

class ApiClient:
    def __init__(self, configuration: Optional[Configuration] = ...) -> None: ...
    def sanitize_for_serialization(self, obj: Any) -> dict[Any, Any]: ...
    def deserialize(self, response: Response, response_type: Type[_T]) -> _T: ...



import datetime
import typing

import kubernetes.client

class V1StatefulSetSpec:
    pod_management_policy: typing.Optional[str]
    replicas: typing.Optional[int]
    revision_history_limit: typing.Optional[int]
    selector: kubernetes.client.V1LabelSelector
    service_name: str
    template: kubernetes.client.V1PodTemplateSpec
    update_strategy: typing.Optional[kubernetes.client.V1StatefulSetUpdateStrategy]
    volume_claim_templates: typing.Optional[
        list[kubernetes.client.V1PersistentVolumeClaim]
    ]
    def __init__(
        self,
        *,
        pod_management_policy: typing.Optional[str] = ...,
        replicas: typing.Optional[int] = ...,
        revision_history_limit: typing.Optional[int] = ...,
        selector: kubernetes.client.V1LabelSelector,
        service_name: str,
        template: kubernetes.client.V1PodTemplateSpec,
        update_strategy: typing.Optional[
            kubernetes.client.V1StatefulSetUpdateStrategy
        ] = ...,
        volume_claim_templates: typing.Optional[
            list[kubernetes.client.V1PersistentVolumeClaim]
        ] = ...
    ) -> None: ...
    def to_dict(self) -> V1StatefulSetSpecDict: ...

class V1StatefulSetSpecDict(typing.TypedDict, total=False):
    podManagementPolicy: typing.Optional[str]
    replicas: typing.Optional[int]
    revisionHistoryLimit: typing.Optional[int]
    selector: kubernetes.client.V1LabelSelectorDict
    serviceName: str
    template: kubernetes.client.V1PodTemplateSpecDict
    updateStrategy: typing.Optional[kubernetes.client.V1StatefulSetUpdateStrategyDict]
    volumeClaimTemplates: typing.Optional[
        list[kubernetes.client.V1PersistentVolumeClaimDict]
    ]



import datetime
import typing

import kubernetes.client

class V1Handler:
    exec: typing.Optional[kubernetes.client.V1ExecAction]
    http_get: typing.Optional[kubernetes.client.V1HTTPGetAction]
    tcp_socket: typing.Optional[kubernetes.client.V1TCPSocketAction]
    def __init__(
        self,
        *,
        exec: typing.Optional[kubernetes.client.V1ExecAction] = ...,
        http_get: typing.Optional[kubernetes.client.V1HTTPGetAction] = ...,
        tcp_socket: typing.Optional[kubernetes.client.V1TCPSocketAction] = ...
    ) -> None: ...
    def to_dict(self) -> V1HandlerDict: ...

class V1HandlerDict(typing.TypedDict, total=False):
    exec: typing.Optional[kubernetes.client.V1ExecActionDict]
    httpGet: typing.Optional[kubernetes.client.V1HTTPGetActionDict]
    tcpSocket: typing.Optional[kubernetes.client.V1TCPSocketActionDict]



import datetime
import typing

import kubernetes.client

class V1beta1RoleBinding:
    api_version: typing.Optional[str]
    kind: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ObjectMeta]
    role_ref: kubernetes.client.V1beta1RoleRef
    subjects: typing.Optional[list[kubernetes.client.RbacV1beta1Subject]]
    def __init__(
        self,
        *,
        api_version: typing.Optional[str] = ...,
        kind: typing.Optional[str] = ...,
        metadata: typing.Optional[kubernetes.client.V1ObjectMeta] = ...,
        role_ref: kubernetes.client.V1beta1RoleRef,
        subjects: typing.Optional[list[kubernetes.client.RbacV1beta1Subject]] = ...
    ) -> None: ...
    def to_dict(self) -> V1beta1RoleBindingDict: ...

class V1beta1RoleBindingDict(typing.TypedDict, total=False):
    apiVersion: typing.Optional[str]
    kind: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ObjectMetaDict]
    roleRef: kubernetes.client.V1beta1RoleRefDict
    subjects: typing.Optional[list[kubernetes.client.RbacV1beta1SubjectDict]]



import datetime
import typing

import kubernetes.client

class V1NamespaceStatus:
    conditions: typing.Optional[list[kubernetes.client.V1NamespaceCondition]]
    phase: typing.Optional[str]
    def __init__(
        self,
        *,
        conditions: typing.Optional[list[kubernetes.client.V1NamespaceCondition]] = ...,
        phase: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1NamespaceStatusDict: ...

class V1NamespaceStatusDict(typing.TypedDict, total=False):
    conditions: typing.Optional[list[kubernetes.client.V1NamespaceConditionDict]]
    phase: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1beta1APIService:
    api_version: typing.Optional[str]
    kind: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ObjectMeta]
    spec: typing.Optional[kubernetes.client.V1beta1APIServiceSpec]
    status: typing.Optional[kubernetes.client.V1beta1APIServiceStatus]
    def __init__(
        self,
        *,
        api_version: typing.Optional[str] = ...,
        kind: typing.Optional[str] = ...,
        metadata: typing.Optional[kubernetes.client.V1ObjectMeta] = ...,
        spec: typing.Optional[kubernetes.client.V1beta1APIServiceSpec] = ...,
        status: typing.Optional[kubernetes.client.V1beta1APIServiceStatus] = ...
    ) -> None: ...
    def to_dict(self) -> V1beta1APIServiceDict: ...

class V1beta1APIServiceDict(typing.TypedDict, total=False):
    apiVersion: typing.Optional[str]
    kind: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ObjectMetaDict]
    spec: typing.Optional[kubernetes.client.V1beta1APIServiceSpecDict]
    status: typing.Optional[kubernetes.client.V1beta1APIServiceStatusDict]



import datetime
import typing

import kubernetes.client

class V1alpha1PolicyRulesWithSubjects:
    non_resource_rules: typing.Optional[
        list[kubernetes.client.V1alpha1NonResourcePolicyRule]
    ]
    resource_rules: typing.Optional[list[kubernetes.client.V1alpha1ResourcePolicyRule]]
    subjects: list[kubernetes.client.FlowcontrolV1alpha1Subject]
    def __init__(
        self,
        *,
        non_resource_rules: typing.Optional[
            list[kubernetes.client.V1alpha1NonResourcePolicyRule]
        ] = ...,
        resource_rules: typing.Optional[
            list[kubernetes.client.V1alpha1ResourcePolicyRule]
        ] = ...,
        subjects: list[kubernetes.client.FlowcontrolV1alpha1Subject]
    ) -> None: ...
    def to_dict(self) -> V1alpha1PolicyRulesWithSubjectsDict: ...

class V1alpha1PolicyRulesWithSubjectsDict(typing.TypedDict, total=False):
    nonResourceRules: typing.Optional[
        list[kubernetes.client.V1alpha1NonResourcePolicyRuleDict]
    ]
    resourceRules: typing.Optional[
        list[kubernetes.client.V1alpha1ResourcePolicyRuleDict]
    ]
    subjects: list[kubernetes.client.FlowcontrolV1alpha1SubjectDict]



import datetime
import typing

import kubernetes.client

class ExtensionsV1beta1IngressSpec:
    backend: typing.Optional[kubernetes.client.ExtensionsV1beta1IngressBackend]
    ingress_class_name: typing.Optional[str]
    rules: typing.Optional[list[kubernetes.client.ExtensionsV1beta1IngressRule]]
    tls: typing.Optional[list[kubernetes.client.ExtensionsV1beta1IngressTLS]]
    def __init__(
        self,
        *,
        backend: typing.Optional[
            kubernetes.client.ExtensionsV1beta1IngressBackend
        ] = ...,
        ingress_class_name: typing.Optional[str] = ...,
        rules: typing.Optional[
            list[kubernetes.client.ExtensionsV1beta1IngressRule]
        ] = ...,
        tls: typing.Optional[list[kubernetes.client.ExtensionsV1beta1IngressTLS]] = ...
    ) -> None: ...
    def to_dict(self) -> ExtensionsV1beta1IngressSpecDict: ...

class ExtensionsV1beta1IngressSpecDict(typing.TypedDict, total=False):
    backend: typing.Optional[kubernetes.client.ExtensionsV1beta1IngressBackendDict]
    ingressClassName: typing.Optional[str]
    rules: typing.Optional[list[kubernetes.client.ExtensionsV1beta1IngressRuleDict]]
    tls: typing.Optional[list[kubernetes.client.ExtensionsV1beta1IngressTLSDict]]



import datetime
import typing

import kubernetes.client

class V1beta1FSGroupStrategyOptions:
    ranges: typing.Optional[list[kubernetes.client.V1beta1IDRange]]
    rule: typing.Optional[str]
    def __init__(
        self,
        *,
        ranges: typing.Optional[list[kubernetes.client.V1beta1IDRange]] = ...,
        rule: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1beta1FSGroupStrategyOptionsDict: ...

class V1beta1FSGroupStrategyOptionsDict(typing.TypedDict, total=False):
    ranges: typing.Optional[list[kubernetes.client.V1beta1IDRangeDict]]
    rule: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1ContainerPort:
    container_port: int
    host_ip: typing.Optional[str]
    host_port: typing.Optional[int]
    name: typing.Optional[str]
    protocol: typing.Optional[str]
    def __init__(
        self,
        *,
        container_port: int,
        host_ip: typing.Optional[str] = ...,
        host_port: typing.Optional[int] = ...,
        name: typing.Optional[str] = ...,
        protocol: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1ContainerPortDict: ...

class V1ContainerPortDict(typing.TypedDict, total=False):
    containerPort: int
    hostIP: typing.Optional[str]
    hostPort: typing.Optional[int]
    name: typing.Optional[str]
    protocol: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1TopologySpreadConstraint:
    label_selector: typing.Optional[kubernetes.client.V1LabelSelector]
    max_skew: int
    topology_key: str
    when_unsatisfiable: str
    def __init__(
        self,
        *,
        label_selector: typing.Optional[kubernetes.client.V1LabelSelector] = ...,
        max_skew: int,
        topology_key: str,
        when_unsatisfiable: str
    ) -> None: ...
    def to_dict(self) -> V1TopologySpreadConstraintDict: ...

class V1TopologySpreadConstraintDict(typing.TypedDict, total=False):
    labelSelector: typing.Optional[kubernetes.client.V1LabelSelectorDict]
    maxSkew: int
    topologyKey: str
    whenUnsatisfiable: str



import datetime
import typing

import kubernetes.client

class V1Preconditions:
    resource_version: typing.Optional[str]
    uid: typing.Optional[str]
    def __init__(
        self,
        *,
        resource_version: typing.Optional[str] = ...,
        uid: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1PreconditionsDict: ...

class V1PreconditionsDict(typing.TypedDict, total=False):
    resourceVersion: typing.Optional[str]
    uid: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1StatefulSetStatus:
    collision_count: typing.Optional[int]
    conditions: typing.Optional[list[kubernetes.client.V1StatefulSetCondition]]
    current_replicas: typing.Optional[int]
    current_revision: typing.Optional[str]
    observed_generation: typing.Optional[int]
    ready_replicas: typing.Optional[int]
    replicas: int
    update_revision: typing.Optional[str]
    updated_replicas: typing.Optional[int]
    def __init__(
        self,
        *,
        collision_count: typing.Optional[int] = ...,
        conditions: typing.Optional[
            list[kubernetes.client.V1StatefulSetCondition]
        ] = ...,
        current_replicas: typing.Optional[int] = ...,
        current_revision: typing.Optional[str] = ...,
        observed_generation: typing.Optional[int] = ...,
        ready_replicas: typing.Optional[int] = ...,
        replicas: int,
        update_revision: typing.Optional[str] = ...,
        updated_replicas: typing.Optional[int] = ...
    ) -> None: ...
    def to_dict(self) -> V1StatefulSetStatusDict: ...

class V1StatefulSetStatusDict(typing.TypedDict, total=False):
    collisionCount: typing.Optional[int]
    conditions: typing.Optional[list[kubernetes.client.V1StatefulSetConditionDict]]
    currentReplicas: typing.Optional[int]
    currentRevision: typing.Optional[str]
    observedGeneration: typing.Optional[int]
    readyReplicas: typing.Optional[int]
    replicas: int
    updateRevision: typing.Optional[str]
    updatedReplicas: typing.Optional[int]



import datetime
import typing

import kubernetes.client

class V1WebhookConversion:
    client_config: typing.Optional[kubernetes.client.ApiextensionsV1WebhookClientConfig]
    conversion_review_versions: list[str]
    def __init__(
        self,
        *,
        client_config: typing.Optional[
            kubernetes.client.ApiextensionsV1WebhookClientConfig
        ] = ...,
        conversion_review_versions: list[str]
    ) -> None: ...
    def to_dict(self) -> V1WebhookConversionDict: ...

class V1WebhookConversionDict(typing.TypedDict, total=False):
    clientConfig: typing.Optional[
        kubernetes.client.ApiextensionsV1WebhookClientConfigDict
    ]
    conversionReviewVersions: list[str]



import datetime
import typing

import kubernetes.client

class V1TypedLocalObjectReference:
    api_group: typing.Optional[str]
    kind: str
    name: str
    def __init__(
        self, *, api_group: typing.Optional[str] = ..., kind: str, name: str
    ) -> None: ...
    def to_dict(self) -> V1TypedLocalObjectReferenceDict: ...

class V1TypedLocalObjectReferenceDict(typing.TypedDict, total=False):
    apiGroup: typing.Optional[str]
    kind: str
    name: str



import datetime
import typing

import kubernetes.client

class V1ContainerState:
    running: typing.Optional[kubernetes.client.V1ContainerStateRunning]
    terminated: typing.Optional[kubernetes.client.V1ContainerStateTerminated]
    waiting: typing.Optional[kubernetes.client.V1ContainerStateWaiting]
    def __init__(
        self,
        *,
        running: typing.Optional[kubernetes.client.V1ContainerStateRunning] = ...,
        terminated: typing.Optional[kubernetes.client.V1ContainerStateTerminated] = ...,
        waiting: typing.Optional[kubernetes.client.V1ContainerStateWaiting] = ...
    ) -> None: ...
    def to_dict(self) -> V1ContainerStateDict: ...

class V1ContainerStateDict(typing.TypedDict, total=False):
    running: typing.Optional[kubernetes.client.V1ContainerStateRunningDict]
    terminated: typing.Optional[kubernetes.client.V1ContainerStateTerminatedDict]
    waiting: typing.Optional[kubernetes.client.V1ContainerStateWaitingDict]



import datetime
import typing

import kubernetes.client

class V1ConfigMapEnvSource:
    name: typing.Optional[str]
    optional: typing.Optional[bool]
    def __init__(
        self, *, name: typing.Optional[str] = ..., optional: typing.Optional[bool] = ...
    ) -> None: ...
    def to_dict(self) -> V1ConfigMapEnvSourceDict: ...

class V1ConfigMapEnvSourceDict(typing.TypedDict, total=False):
    name: typing.Optional[str]
    optional: typing.Optional[bool]



import datetime
import typing

import kubernetes.client

class V1ContainerStatus:
    container_id: typing.Optional[str]
    image: str
    image_id: str
    last_state: typing.Optional[kubernetes.client.V1ContainerState]
    name: str
    ready: bool
    restart_count: int
    started: typing.Optional[bool]
    state: typing.Optional[kubernetes.client.V1ContainerState]
    def __init__(
        self,
        *,
        container_id: typing.Optional[str] = ...,
        image: str,
        image_id: str,
        last_state: typing.Optional[kubernetes.client.V1ContainerState] = ...,
        name: str,
        ready: bool,
        restart_count: int,
        started: typing.Optional[bool] = ...,
        state: typing.Optional[kubernetes.client.V1ContainerState] = ...
    ) -> None: ...
    def to_dict(self) -> V1ContainerStatusDict: ...

class V1ContainerStatusDict(typing.TypedDict, total=False):
    containerID: typing.Optional[str]
    image: str
    imageID: str
    lastState: typing.Optional[kubernetes.client.V1ContainerStateDict]
    name: str
    ready: bool
    restartCount: int
    started: typing.Optional[bool]
    state: typing.Optional[kubernetes.client.V1ContainerStateDict]



import datetime
import typing

import kubernetes.client

class V1IngressBackend:
    resource: typing.Optional[kubernetes.client.V1TypedLocalObjectReference]
    service: typing.Optional[kubernetes.client.V1IngressServiceBackend]
    def __init__(
        self,
        *,
        resource: typing.Optional[kubernetes.client.V1TypedLocalObjectReference] = ...,
        service: typing.Optional[kubernetes.client.V1IngressServiceBackend] = ...
    ) -> None: ...
    def to_dict(self) -> V1IngressBackendDict: ...

class V1IngressBackendDict(typing.TypedDict, total=False):
    resource: typing.Optional[kubernetes.client.V1TypedLocalObjectReferenceDict]
    service: typing.Optional[kubernetes.client.V1IngressServiceBackendDict]



import datetime
import typing

import kubernetes.client

class V1SessionAffinityConfig:
    client_ip: typing.Optional[kubernetes.client.V1ClientIPConfig]
    def __init__(
        self, *, client_ip: typing.Optional[kubernetes.client.V1ClientIPConfig] = ...
    ) -> None: ...
    def to_dict(self) -> V1SessionAffinityConfigDict: ...

class V1SessionAffinityConfigDict(typing.TypedDict, total=False):
    clientIP: typing.Optional[kubernetes.client.V1ClientIPConfigDict]



import datetime
import typing

import kubernetes.client

class V1RuleWithOperations:
    api_groups: typing.Optional[list[str]]
    api_versions: typing.Optional[list[str]]
    operations: typing.Optional[list[str]]
    resources: typing.Optional[list[str]]
    scope: typing.Optional[str]
    def __init__(
        self,
        *,
        api_groups: typing.Optional[list[str]] = ...,
        api_versions: typing.Optional[list[str]] = ...,
        operations: typing.Optional[list[str]] = ...,
        resources: typing.Optional[list[str]] = ...,
        scope: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1RuleWithOperationsDict: ...

class V1RuleWithOperationsDict(typing.TypedDict, total=False):
    apiGroups: typing.Optional[list[str]]
    apiVersions: typing.Optional[list[str]]
    operations: typing.Optional[list[str]]
    resources: typing.Optional[list[str]]
    scope: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1PodIP:
    ip: typing.Optional[str]
    def __init__(self, *, ip: typing.Optional[str] = ...) -> None: ...
    def to_dict(self) -> V1PodIPDict: ...

class V1PodIPDict(typing.TypedDict, total=False):
    ip: typing.Optional[str]
